# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/trino/v1/catalog.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/trino/v1/catalog.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#yandex/cloud/trino/v1/catalog.proto\x12\x15yandex.cloud.trino.v1\x1a\x1dyandex/cloud/validation.proto\"\xe6\x05\n\tConnector\x12\x34\n\x04hive\x18\x01 \x01(\x0b\x32$.yandex.cloud.trino.v1.HiveConnectorH\x00\x12:\n\x07iceberg\x18\x02 \x01(\x0b\x32\'.yandex.cloud.trino.v1.IcebergConnectorH\x00\x12?\n\ndelta_lake\x18\x03 \x01(\x0b\x32).yandex.cloud.trino.v1.DeltaLakeConnectorH\x00\x12@\n\npostgresql\x18\x04 \x01(\x0b\x32*.yandex.cloud.trino.v1.PostgresqlConnectorH\x00\x12@\n\nclickhouse\x18\x05 \x01(\x0b\x32*.yandex.cloud.trino.v1.ClickhouseConnectorH\x00\x12\x34\n\x04tpch\x18\x06 \x01(\x0b\x32$.yandex.cloud.trino.v1.TPCHConnectorH\x00\x12\x36\n\x05tpcds\x18\x07 \x01(\x0b\x32%.yandex.cloud.trino.v1.TPCDSConnectorH\x00\x12\x38\n\x06oracle\x18\x08 \x01(\x0b\x32&.yandex.cloud.trino.v1.OracleConnectorH\x00\x12>\n\tsqlserver\x18\t \x01(\x0b\x32).yandex.cloud.trino.v1.SQLServerConnectorH\x00\x12\x34\n\x04hudi\x18\n \x01(\x0b\x32$.yandex.cloud.trino.v1.HudiConnectorH\x00\x12\x36\n\x05mysql\x18\x0b \x01(\x0b\x32%.yandex.cloud.trino.v1.MysqlConnectorH\x00\x12>\n\tgreenplum\x18\x0c \x01(\x0b\x32).yandex.cloud.trino.v1.GreenplumConnectorH\x00\x42\x0c\n\x04type\x12\x04\xc0\xc1\x31\x01\"\xd8\x01\n\x07\x43\x61talog\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x33\n\tconnector\x18\x03 \x01(\x0b\x32 .yandex.cloud.trino.v1.Connector\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12:\n\x06labels\x18\x05 \x03(\x0b\x32*.yandex.cloud.trino.v1.Catalog.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc2\x02\n\x0b\x43\x61talogSpec\x12,\n\x04name\x18\x01 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x39\n\tconnector\x18\x02 \x01(\x0b\x32 .yandex.cloud.trino.v1.ConnectorB\x04\xe8\xc7\x31\x01\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12{\n\x06labels\x18\x04 \x03(\x0b\x32..yandex.cloud.trino.v1.CatalogSpec.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc5\x02\n\x11\x43\x61talogUpdateSpec\x12(\n\x04name\x18\x01 \x01(\tB\x1a\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x33\n\tconnector\x18\x02 \x01(\x0b\x32 .yandex.cloud.trino.v1.Connector\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x81\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x34.yandex.cloud.trino.v1.CatalogUpdateSpec.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8d\x01\n\tMetastore\x12>\n\x04hive\x18\x01 \x01(\x0b\x32..yandex.cloud.trino.v1.Metastore.HiveMetastoreH\x00\x1a\x32\n\rHiveMetastore\x12\r\n\x03uri\x18\x01 \x01(\tH\x00\x42\x12\n\nconnection\x12\x04\xc0\xc1\x31\x01\x42\x0c\n\x04type\x12\x04\xc0\xc1\x31\x01\"\xc2\x02\n\nFileSystem\x12<\n\x02s3\x18\x01 \x01(\x0b\x32..yandex.cloud.trino.v1.FileSystem.S3FileSystemH\x00\x12M\n\x0b\x65xternal_s3\x18\x02 \x01(\x0b\x32\x36.yandex.cloud.trino.v1.FileSystem.ExternalS3FileSystemH\x00\x1a\x0e\n\x0cS3FileSystem\x1a\x88\x01\n\x14\x45xternalS3FileSystem\x12\x1c\n\x0e\x61ws_access_key\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1c\n\x0e\x61ws_secret_key\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1a\n\x0c\x61ws_endpoint\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x18\n\naws_region\x18\x04 \x01(\tB\x04\xe8\xc7\x31\x01\x42\x0c\n\x04type\x12\x04\xc0\xc1\x31\x01\"\xef\x02\n\rHiveConnector\x12\x39\n\tmetastore\x18\x01 \x01(\x0b\x32 .yandex.cloud.trino.v1.MetastoreB\x04\xe8\xc7\x31\x01\x12;\n\nfilesystem\x18\x02 \x01(\x0b\x32!.yandex.cloud.trino.v1.FileSystemB\x04\xe8\xc7\x31\x01\x12\xa8\x01\n\x15\x61\x64\x64itional_properties\x18\x03 \x03(\x0b\x32>.yandex.cloud.trino.v1.HiveConnector.AdditionalPropertiesEntryBI\xf2\xc7\x31\x15[-_0-9a-zA-Z.,:\\/_ ]*\x82\xc8\x31\x05<=256\x8a\xc8\x31\x05<=128\xb2\xc8\x31\x1a\x12\x11[a-z][-_0-9a-z.]*\x1a\x05\x31-128\x1a;\n\x19\x41\x64\x64itionalPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf5\x02\n\x10IcebergConnector\x12\x39\n\tmetastore\x18\x01 \x01(\x0b\x32 .yandex.cloud.trino.v1.MetastoreB\x04\xe8\xc7\x31\x01\x12;\n\nfilesystem\x18\x02 \x01(\x0b\x32!.yandex.cloud.trino.v1.FileSystemB\x04\xe8\xc7\x31\x01\x12\xab\x01\n\x15\x61\x64\x64itional_properties\x18\x03 \x03(\x0b\x32\x41.yandex.cloud.trino.v1.IcebergConnector.AdditionalPropertiesEntryBI\xf2\xc7\x31\x15[-_0-9a-zA-Z.,:\\/_ ]*\x82\xc8\x31\x05<=256\x8a\xc8\x31\x05<=128\xb2\xc8\x31\x1a\x12\x11[a-z][-_0-9a-z.]*\x1a\x05\x31-128\x1a;\n\x19\x41\x64\x64itionalPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf9\x02\n\x12\x44\x65ltaLakeConnector\x12\x39\n\tmetastore\x18\x01 \x01(\x0b\x32 .yandex.cloud.trino.v1.MetastoreB\x04\xe8\xc7\x31\x01\x12;\n\nfilesystem\x18\x02 \x01(\x0b\x32!.yandex.cloud.trino.v1.FileSystemB\x04\xe8\xc7\x31\x01\x12\xad\x01\n\x15\x61\x64\x64itional_properties\x18\x03 \x03(\x0b\x32\x43.yandex.cloud.trino.v1.DeltaLakeConnector.AdditionalPropertiesEntryBI\xf2\xc7\x31\x15[-_0-9a-zA-Z.,:\\/_ ]*\x82\xc8\x31\x05<=256\x8a\xc8\x31\x05<=128\xb2\xc8\x31\x1a\x12\x11[a-z][-_0-9a-z.]*\x1a\x05\x31-128\x1a;\n\x19\x41\x64\x64itionalPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xef\x02\n\rHudiConnector\x12\x39\n\tmetastore\x18\x01 \x01(\x0b\x32 .yandex.cloud.trino.v1.MetastoreB\x04\xe8\xc7\x31\x01\x12;\n\nfilesystem\x18\x02 \x01(\x0b\x32!.yandex.cloud.trino.v1.FileSystemB\x04\xe8\xc7\x31\x01\x12\xa8\x01\n\x15\x61\x64\x64itional_properties\x18\x03 \x03(\x0b\x32>.yandex.cloud.trino.v1.HudiConnector.AdditionalPropertiesEntryBI\xf2\xc7\x31\x15[-_0-9a-zA-Z.,:\\/_ ]*\x82\xc8\x31\x05<=256\x8a\xc8\x31\x05<=128\xb2\xc8\x31\x1a\x12\x11[a-z][-_0-9a-z.]*\x1a\x05\x31-128\x1a;\n\x19\x41\x64\x64itionalPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xdc\x05\n\x14PostgresqlConnection\x12K\n\non_premise\x18\x01 \x01(\x0b\x32\x35.yandex.cloud.trino.v1.PostgresqlConnection.OnPremiseH\x00\x12[\n\x12\x63onnection_manager\x18\x02 \x01(\x0b\x32=.yandex.cloud.trino.v1.PostgresqlConnection.ConnectionManagerH\x00\x1a\xa6\x01\n\tOnPremise\x12\x45\n\x0e\x63onnection_url\x18\x01 \x01(\tB-\xe8\xc7\x31\x01\xf2\xc7\x31%^jdbc:postgresql://(?:.+:\\d+)/(?:.*)$\x12\x31\n\tuser_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1f\n\x08password\x18\x03 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05\x30-128\x1a\xe2\x02\n\x11\x43onnectionManager\x12#\n\rconnection_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04\x31-50\x12\x30\n\x08\x64\x61tabase\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\xb8\x01\n\x15\x63onnection_properties\x18\x03 \x03(\x0b\x32W.yandex.cloud.trino.v1.PostgresqlConnection.ConnectionManager.ConnectionPropertiesEntryB@\xf2\xc7\x31\x14[-_0-9a-zA-Z.,:\\/_]*\x82\xc8\x31\x05<=256\x8a\xc8\x31\x05<=128\xb2\xc8\x31\x12\x12\t[a-zA-Z]*\x1a\x05\x31-128\x1a;\n\x19\x43onnectionPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0c\n\x04type\x12\x04\xc0\xc1\x31\x01\"\xc4\x02\n\x13PostgresqlConnector\x12?\n\nconnection\x18\x01 \x01(\x0b\x32+.yandex.cloud.trino.v1.PostgresqlConnection\x12\xae\x01\n\x15\x61\x64\x64itional_properties\x18\x02 \x03(\x0b\x32\x44.yandex.cloud.trino.v1.PostgresqlConnector.AdditionalPropertiesEntryBI\xf2\xc7\x31\x15[-_0-9a-zA-Z.,:\\/_ ]*\x82\xc8\x31\x05<=256\x8a\xc8\x31\x05<=128\xb2\xc8\x31\x1a\x12\x11[a-z][-_0-9a-z.]*\x1a\x05\x31-128\x1a;\n\x19\x41\x64\x64itionalPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xdd\x05\n\x14\x43lickhouseConnection\x12K\n\non_premise\x18\x01 \x01(\x0b\x32\x35.yandex.cloud.trino.v1.ClickhouseConnection.OnPremiseH\x00\x12[\n\x12\x63onnection_manager\x18\x02 \x01(\x0b\x32=.yandex.cloud.trino.v1.ClickhouseConnection.ConnectionManagerH\x00\x1a\xa6\x01\n\tOnPremise\x12\x45\n\x0e\x63onnection_url\x18\x01 \x01(\tB-\xe8\xc7\x31\x01\xf2\xc7\x31%^jdbc:clickhouse://(?:.+:\\d+)/(?:.*)$\x12\x31\n\tuser_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1f\n\x08password\x18\x03 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05\x30-128\x1a\xe3\x02\n\x11\x43onnectionManager\x12#\n\rconnection_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04\x31-50\x12\x30\n\x08\x64\x61tabase\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\xb9\x01\n\x15\x63onnection_properties\x18\x03 \x03(\x0b\x32W.yandex.cloud.trino.v1.ClickhouseConnection.ConnectionManager.ConnectionPropertiesEntryBA\xf2\xc7\x31\x14[-_0-9a-zA-Z.,:\\/_]*\x82\xc8\x31\x05<=256\x8a\xc8\x31\x05<=128\xb2\xc8\x31\x13\x12\n[a-zA-Z_]*\x1a\x05\x31-128\x1a;\n\x19\x43onnectionPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0c\n\x04type\x12\x04\xc0\xc1\x31\x01\"\xc4\x02\n\x13\x43lickhouseConnector\x12?\n\nconnection\x18\x01 \x01(\x0b\x32+.yandex.cloud.trino.v1.ClickhouseConnection\x12\xae\x01\n\x15\x61\x64\x64itional_properties\x18\x02 \x03(\x0b\x32\x44.yandex.cloud.trino.v1.ClickhouseConnector.AdditionalPropertiesEntryBI\xf2\xc7\x31\x15[-_0-9a-zA-Z.,:\\/_ ]*\x82\xc8\x31\x05<=256\x8a\xc8\x31\x05<=128\xb2\xc8\x31\x1a\x12\x11[a-z][-_0-9a-z.]*\x1a\x05\x31-128\x1a;\n\x19\x41\x64\x64itionalPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf7\x01\n\rTPCHConnector\x12\xa8\x01\n\x15\x61\x64\x64itional_properties\x18\x01 \x03(\x0b\x32>.yandex.cloud.trino.v1.TPCHConnector.AdditionalPropertiesEntryBI\xf2\xc7\x31\x15[-_0-9a-zA-Z.,:\\/_ ]*\x82\xc8\x31\x05<=256\x8a\xc8\x31\x05<=128\xb2\xc8\x31\x1a\x12\x11[a-z][-_0-9a-z.]*\x1a\x05\x31-128\x1a;\n\x19\x41\x64\x64itionalPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf9\x01\n\x0eTPCDSConnector\x12\xa9\x01\n\x15\x61\x64\x64itional_properties\x18\x01 \x03(\x0b\x32?.yandex.cloud.trino.v1.TPCDSConnector.AdditionalPropertiesEntryBI\xf2\xc7\x31\x15[-_0-9a-zA-Z.,:\\/_ ]*\x82\xc8\x31\x05<=256\x8a\xc8\x31\x05<=128\xb2\xc8\x31\x1a\x12\x11[a-z][-_0-9a-z.]*\x1a\x05\x31-128\x1a;\n\x19\x41\x64\x64itionalPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x82\x02\n\x10OracleConnection\x12G\n\non_premise\x18\x01 \x01(\x0b\x32\x31.yandex.cloud.trino.v1.OracleConnection.OnPremiseH\x00\x1a\x96\x01\n\tOnPremise\x12\x35\n\x0e\x63onnection_url\x18\x01 \x01(\tB\x1d\xe8\xc7\x31\x01\xf2\xc7\x31\x15^jdbc:oracle:(?s:.*)$\x12\x31\n\tuser_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1f\n\x08password\x18\x03 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05\x30-128B\x0c\n\x04type\x12\x04\xc0\xc1\x31\x01\"\xb8\x02\n\x0fOracleConnector\x12;\n\nconnection\x18\x01 \x01(\x0b\x32\'.yandex.cloud.trino.v1.OracleConnection\x12\xaa\x01\n\x15\x61\x64\x64itional_properties\x18\x02 \x03(\x0b\x32@.yandex.cloud.trino.v1.OracleConnector.AdditionalPropertiesEntryBI\xf2\xc7\x31\x15[-_0-9a-zA-Z.,:\\/_ ]*\x82\xc8\x31\x05<=256\x8a\xc8\x31\x05<=128\xb2\xc8\x31\x1a\x12\x11[a-z][-_0-9a-z.]*\x1a\x05\x31-128\x1a;\n\x19\x41\x64\x64itionalPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8b\x02\n\x13SQLServerConnection\x12J\n\non_premise\x18\x01 \x01(\x0b\x32\x34.yandex.cloud.trino.v1.SQLServerConnection.OnPremiseH\x00\x1a\x99\x01\n\tOnPremise\x12\x38\n\x0e\x63onnection_url\x18\x01 \x01(\tB \xe8\xc7\x31\x01\xf2\xc7\x31\x18^jdbc:sqlserver:(?s:.*)$\x12\x31\n\tuser_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1f\n\x08password\x18\x03 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05\x30-128B\x0c\n\x04type\x12\x04\xc0\xc1\x31\x01\"\xc1\x02\n\x12SQLServerConnector\x12>\n\nconnection\x18\x01 \x01(\x0b\x32*.yandex.cloud.trino.v1.SQLServerConnection\x12\xad\x01\n\x15\x61\x64\x64itional_properties\x18\x02 \x03(\x0b\x32\x43.yandex.cloud.trino.v1.SQLServerConnector.AdditionalPropertiesEntryBI\xf2\xc7\x31\x15[-_0-9a-zA-Z.,:\\/_ ]*\x82\xc8\x31\x05<=256\x8a\xc8\x31\x05<=128\xb2\xc8\x31\x1a\x12\x11[a-z][-_0-9a-z.]*\x1a\x05\x31-128\x1a;\n\x19\x41\x64\x64itionalPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x93\x05\n\x0fMysqlConnection\x12\x46\n\non_premise\x18\x01 \x01(\x0b\x32\x30.yandex.cloud.trino.v1.MysqlConnection.OnPremiseH\x00\x12V\n\x12\x63onnection_manager\x18\x02 \x01(\x0b\x32\x38.yandex.cloud.trino.v1.MysqlConnection.ConnectionManagerH\x00\x1a\xa2\x01\n\tOnPremise\x12\x41\n\x0e\x63onnection_url\x18\x01 \x01(\tB)\xe8\xc7\x31\x01\xf2\xc7\x31!^jdbc:mysql://(?:.+:\\d+)(?:/?.*)$\x12\x31\n\tuser_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1f\n\x08password\x18\x03 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05\x30-128\x1a\xac\x02\n\x11\x43onnectionManager\x12#\n\rconnection_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04\x31-50\x12\xb4\x01\n\x15\x63onnection_properties\x18\x02 \x03(\x0b\x32R.yandex.cloud.trino.v1.MysqlConnection.ConnectionManager.ConnectionPropertiesEntryBA\xf2\xc7\x31\x14[-_0-9a-zA-Z.,:\\/_]*\x82\xc8\x31\x05<=256\x8a\xc8\x31\x05<=128\xb2\xc8\x31\x13\x12\n[a-zA-Z_]*\x1a\x05\x31-128\x1a;\n\x19\x43onnectionPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0c\n\x04type\x12\x04\xc0\xc1\x31\x01\"\xb5\x02\n\x0eMysqlConnector\x12:\n\nconnection\x18\x01 \x01(\x0b\x32&.yandex.cloud.trino.v1.MysqlConnection\x12\xa9\x01\n\x15\x61\x64\x64itional_properties\x18\x02 \x03(\x0b\x32?.yandex.cloud.trino.v1.MysqlConnector.AdditionalPropertiesEntryBI\xf2\xc7\x31\x15[-_0-9a-zA-Z.,:\\/_ ]*\x82\xc8\x31\x05<=256\x8a\xc8\x31\x05<=128\xb2\xc8\x31\x1a\x12\x11[a-z][-_0-9a-z.]*\x1a\x05\x31-128\x1a;\n\x19\x41\x64\x64itionalPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd8\x05\n\x13GreenplumConnection\x12J\n\non_premise\x18\x01 \x01(\x0b\x32\x34.yandex.cloud.trino.v1.GreenplumConnection.OnPremiseH\x00\x12Z\n\x12\x63onnection_manager\x18\x02 \x01(\x0b\x32<.yandex.cloud.trino.v1.GreenplumConnection.ConnectionManagerH\x00\x1a\xa6\x01\n\tOnPremise\x12\x45\n\x0e\x63onnection_url\x18\x01 \x01(\tB-\xe8\xc7\x31\x01\xf2\xc7\x31%^jdbc:postgresql://(?:.+:\\d+)/(?:.*)$\x12\x31\n\tuser_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1f\n\x08password\x18\x03 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05\x30-128\x1a\xe1\x02\n\x11\x43onnectionManager\x12#\n\rconnection_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04\x31-50\x12\x30\n\x08\x64\x61tabase\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\xb7\x01\n\x15\x63onnection_properties\x18\x03 \x03(\x0b\x32V.yandex.cloud.trino.v1.GreenplumConnection.ConnectionManager.ConnectionPropertiesEntryB@\xf2\xc7\x31\x14[-_0-9a-zA-Z.,:\\/_]*\x82\xc8\x31\x05<=256\x8a\xc8\x31\x05<=128\xb2\xc8\x31\x12\x12\t[a-zA-Z]*\x1a\x05\x31-128\x1a;\n\x19\x43onnectionPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0c\n\x04type\x12\x04\xc0\xc1\x31\x01\"\xc1\x02\n\x12GreenplumConnector\x12>\n\nconnection\x18\x01 \x01(\x0b\x32*.yandex.cloud.trino.v1.GreenplumConnection\x12\xad\x01\n\x15\x61\x64\x64itional_properties\x18\x02 \x03(\x0b\x32\x43.yandex.cloud.trino.v1.GreenplumConnector.AdditionalPropertiesEntryBI\xf2\xc7\x31\x15[-_0-9a-zA-Z.,:\\/_ ]*\x82\xc8\x31\x05<=256\x8a\xc8\x31\x05<=128\xb2\xc8\x31\x1a\x12\x11[a-z][-_0-9a-z.]*\x1a\x05\x31-128\x1a;\n\x19\x41\x64\x64itionalPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\\\n\x19yandex.cloud.api.trino.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/trino/v1;trinob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.trino.v1.catalog_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031yandex.cloud.api.trino.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/trino/v1;trino'
  _globals['_CONNECTOR'].oneofs_by_name['type']._loaded_options = None
  _globals['_CONNECTOR'].oneofs_by_name['type']._serialized_options = b'\300\3011\001'
  _globals['_CATALOG_LABELSENTRY']._loaded_options = None
  _globals['_CATALOG_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CATALOGSPEC_LABELSENTRY']._loaded_options = None
  _globals['_CATALOGSPEC_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CATALOGSPEC'].fields_by_name['name']._loaded_options = None
  _globals['_CATALOGSPEC'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_CATALOGSPEC'].fields_by_name['connector']._loaded_options = None
  _globals['_CATALOGSPEC'].fields_by_name['connector']._serialized_options = b'\350\3071\001'
  _globals['_CATALOGSPEC'].fields_by_name['description']._loaded_options = None
  _globals['_CATALOGSPEC'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CATALOGSPEC'].fields_by_name['labels']._loaded_options = None
  _globals['_CATALOGSPEC'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_CATALOGUPDATESPEC_LABELSENTRY']._loaded_options = None
  _globals['_CATALOGUPDATESPEC_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CATALOGUPDATESPEC'].fields_by_name['name']._loaded_options = None
  _globals['_CATALOGUPDATESPEC'].fields_by_name['name']._serialized_options = b'\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_CATALOGUPDATESPEC'].fields_by_name['description']._loaded_options = None
  _globals['_CATALOGUPDATESPEC'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CATALOGUPDATESPEC'].fields_by_name['labels']._loaded_options = None
  _globals['_CATALOGUPDATESPEC'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_METASTORE_HIVEMETASTORE'].oneofs_by_name['connection']._loaded_options = None
  _globals['_METASTORE_HIVEMETASTORE'].oneofs_by_name['connection']._serialized_options = b'\300\3011\001'
  _globals['_METASTORE'].oneofs_by_name['type']._loaded_options = None
  _globals['_METASTORE'].oneofs_by_name['type']._serialized_options = b'\300\3011\001'
  _globals['_FILESYSTEM_EXTERNALS3FILESYSTEM'].fields_by_name['aws_access_key']._loaded_options = None
  _globals['_FILESYSTEM_EXTERNALS3FILESYSTEM'].fields_by_name['aws_access_key']._serialized_options = b'\350\3071\001'
  _globals['_FILESYSTEM_EXTERNALS3FILESYSTEM'].fields_by_name['aws_secret_key']._loaded_options = None
  _globals['_FILESYSTEM_EXTERNALS3FILESYSTEM'].fields_by_name['aws_secret_key']._serialized_options = b'\350\3071\001'
  _globals['_FILESYSTEM_EXTERNALS3FILESYSTEM'].fields_by_name['aws_endpoint']._loaded_options = None
  _globals['_FILESYSTEM_EXTERNALS3FILESYSTEM'].fields_by_name['aws_endpoint']._serialized_options = b'\350\3071\001'
  _globals['_FILESYSTEM_EXTERNALS3FILESYSTEM'].fields_by_name['aws_region']._loaded_options = None
  _globals['_FILESYSTEM_EXTERNALS3FILESYSTEM'].fields_by_name['aws_region']._serialized_options = b'\350\3071\001'
  _globals['_FILESYSTEM'].oneofs_by_name['type']._loaded_options = None
  _globals['_FILESYSTEM'].oneofs_by_name['type']._serialized_options = b'\300\3011\001'
  _globals['_HIVECONNECTOR_ADDITIONALPROPERTIESENTRY']._loaded_options = None
  _globals['_HIVECONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_HIVECONNECTOR'].fields_by_name['metastore']._loaded_options = None
  _globals['_HIVECONNECTOR'].fields_by_name['metastore']._serialized_options = b'\350\3071\001'
  _globals['_HIVECONNECTOR'].fields_by_name['filesystem']._loaded_options = None
  _globals['_HIVECONNECTOR'].fields_by_name['filesystem']._serialized_options = b'\350\3071\001'
  _globals['_HIVECONNECTOR'].fields_by_name['additional_properties']._loaded_options = None
  _globals['_HIVECONNECTOR'].fields_by_name['additional_properties']._serialized_options = b'\362\3071\025[-_0-9a-zA-Z.,:\\/_ ]*\202\3101\005<=256\212\3101\005<=128\262\3101\032\022\021[a-z][-_0-9a-z.]*\032\0051-128'
  _globals['_ICEBERGCONNECTOR_ADDITIONALPROPERTIESENTRY']._loaded_options = None
  _globals['_ICEBERGCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_ICEBERGCONNECTOR'].fields_by_name['metastore']._loaded_options = None
  _globals['_ICEBERGCONNECTOR'].fields_by_name['metastore']._serialized_options = b'\350\3071\001'
  _globals['_ICEBERGCONNECTOR'].fields_by_name['filesystem']._loaded_options = None
  _globals['_ICEBERGCONNECTOR'].fields_by_name['filesystem']._serialized_options = b'\350\3071\001'
  _globals['_ICEBERGCONNECTOR'].fields_by_name['additional_properties']._loaded_options = None
  _globals['_ICEBERGCONNECTOR'].fields_by_name['additional_properties']._serialized_options = b'\362\3071\025[-_0-9a-zA-Z.,:\\/_ ]*\202\3101\005<=256\212\3101\005<=128\262\3101\032\022\021[a-z][-_0-9a-z.]*\032\0051-128'
  _globals['_DELTALAKECONNECTOR_ADDITIONALPROPERTIESENTRY']._loaded_options = None
  _globals['_DELTALAKECONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_DELTALAKECONNECTOR'].fields_by_name['metastore']._loaded_options = None
  _globals['_DELTALAKECONNECTOR'].fields_by_name['metastore']._serialized_options = b'\350\3071\001'
  _globals['_DELTALAKECONNECTOR'].fields_by_name['filesystem']._loaded_options = None
  _globals['_DELTALAKECONNECTOR'].fields_by_name['filesystem']._serialized_options = b'\350\3071\001'
  _globals['_DELTALAKECONNECTOR'].fields_by_name['additional_properties']._loaded_options = None
  _globals['_DELTALAKECONNECTOR'].fields_by_name['additional_properties']._serialized_options = b'\362\3071\025[-_0-9a-zA-Z.,:\\/_ ]*\202\3101\005<=256\212\3101\005<=128\262\3101\032\022\021[a-z][-_0-9a-z.]*\032\0051-128'
  _globals['_HUDICONNECTOR_ADDITIONALPROPERTIESENTRY']._loaded_options = None
  _globals['_HUDICONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_HUDICONNECTOR'].fields_by_name['metastore']._loaded_options = None
  _globals['_HUDICONNECTOR'].fields_by_name['metastore']._serialized_options = b'\350\3071\001'
  _globals['_HUDICONNECTOR'].fields_by_name['filesystem']._loaded_options = None
  _globals['_HUDICONNECTOR'].fields_by_name['filesystem']._serialized_options = b'\350\3071\001'
  _globals['_HUDICONNECTOR'].fields_by_name['additional_properties']._loaded_options = None
  _globals['_HUDICONNECTOR'].fields_by_name['additional_properties']._serialized_options = b'\362\3071\025[-_0-9a-zA-Z.,:\\/_ ]*\202\3101\005<=256\212\3101\005<=128\262\3101\032\022\021[a-z][-_0-9a-z.]*\032\0051-128'
  _globals['_POSTGRESQLCONNECTION_ONPREMISE'].fields_by_name['connection_url']._loaded_options = None
  _globals['_POSTGRESQLCONNECTION_ONPREMISE'].fields_by_name['connection_url']._serialized_options = b'\350\3071\001\362\3071%^jdbc:postgresql://(?:.+:\\d+)/(?:.*)$'
  _globals['_POSTGRESQLCONNECTION_ONPREMISE'].fields_by_name['user_name']._loaded_options = None
  _globals['_POSTGRESQLCONNECTION_ONPREMISE'].fields_by_name['user_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_POSTGRESQLCONNECTION_ONPREMISE'].fields_by_name['password']._loaded_options = None
  _globals['_POSTGRESQLCONNECTION_ONPREMISE'].fields_by_name['password']._serialized_options = b'\350\3071\001\212\3101\0050-128'
  _globals['_POSTGRESQLCONNECTION_CONNECTIONMANAGER_CONNECTIONPROPERTIESENTRY']._loaded_options = None
  _globals['_POSTGRESQLCONNECTION_CONNECTIONMANAGER_CONNECTIONPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_POSTGRESQLCONNECTION_CONNECTIONMANAGER'].fields_by_name['connection_id']._loaded_options = None
  _globals['_POSTGRESQLCONNECTION_CONNECTIONMANAGER'].fields_by_name['connection_id']._serialized_options = b'\350\3071\001\212\3101\0041-50'
  _globals['_POSTGRESQLCONNECTION_CONNECTIONMANAGER'].fields_by_name['database']._loaded_options = None
  _globals['_POSTGRESQLCONNECTION_CONNECTIONMANAGER'].fields_by_name['database']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_POSTGRESQLCONNECTION_CONNECTIONMANAGER'].fields_by_name['connection_properties']._loaded_options = None
  _globals['_POSTGRESQLCONNECTION_CONNECTIONMANAGER'].fields_by_name['connection_properties']._serialized_options = b'\362\3071\024[-_0-9a-zA-Z.,:\\/_]*\202\3101\005<=256\212\3101\005<=128\262\3101\022\022\t[a-zA-Z]*\032\0051-128'
  _globals['_POSTGRESQLCONNECTION'].oneofs_by_name['type']._loaded_options = None
  _globals['_POSTGRESQLCONNECTION'].oneofs_by_name['type']._serialized_options = b'\300\3011\001'
  _globals['_POSTGRESQLCONNECTOR_ADDITIONALPROPERTIESENTRY']._loaded_options = None
  _globals['_POSTGRESQLCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_POSTGRESQLCONNECTOR'].fields_by_name['additional_properties']._loaded_options = None
  _globals['_POSTGRESQLCONNECTOR'].fields_by_name['additional_properties']._serialized_options = b'\362\3071\025[-_0-9a-zA-Z.,:\\/_ ]*\202\3101\005<=256\212\3101\005<=128\262\3101\032\022\021[a-z][-_0-9a-z.]*\032\0051-128'
  _globals['_CLICKHOUSECONNECTION_ONPREMISE'].fields_by_name['connection_url']._loaded_options = None
  _globals['_CLICKHOUSECONNECTION_ONPREMISE'].fields_by_name['connection_url']._serialized_options = b'\350\3071\001\362\3071%^jdbc:clickhouse://(?:.+:\\d+)/(?:.*)$'
  _globals['_CLICKHOUSECONNECTION_ONPREMISE'].fields_by_name['user_name']._loaded_options = None
  _globals['_CLICKHOUSECONNECTION_ONPREMISE'].fields_by_name['user_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_CLICKHOUSECONNECTION_ONPREMISE'].fields_by_name['password']._loaded_options = None
  _globals['_CLICKHOUSECONNECTION_ONPREMISE'].fields_by_name['password']._serialized_options = b'\350\3071\001\212\3101\0050-128'
  _globals['_CLICKHOUSECONNECTION_CONNECTIONMANAGER_CONNECTIONPROPERTIESENTRY']._loaded_options = None
  _globals['_CLICKHOUSECONNECTION_CONNECTIONMANAGER_CONNECTIONPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_CLICKHOUSECONNECTION_CONNECTIONMANAGER'].fields_by_name['connection_id']._loaded_options = None
  _globals['_CLICKHOUSECONNECTION_CONNECTIONMANAGER'].fields_by_name['connection_id']._serialized_options = b'\350\3071\001\212\3101\0041-50'
  _globals['_CLICKHOUSECONNECTION_CONNECTIONMANAGER'].fields_by_name['database']._loaded_options = None
  _globals['_CLICKHOUSECONNECTION_CONNECTIONMANAGER'].fields_by_name['database']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_CLICKHOUSECONNECTION_CONNECTIONMANAGER'].fields_by_name['connection_properties']._loaded_options = None
  _globals['_CLICKHOUSECONNECTION_CONNECTIONMANAGER'].fields_by_name['connection_properties']._serialized_options = b'\362\3071\024[-_0-9a-zA-Z.,:\\/_]*\202\3101\005<=256\212\3101\005<=128\262\3101\023\022\n[a-zA-Z_]*\032\0051-128'
  _globals['_CLICKHOUSECONNECTION'].oneofs_by_name['type']._loaded_options = None
  _globals['_CLICKHOUSECONNECTION'].oneofs_by_name['type']._serialized_options = b'\300\3011\001'
  _globals['_CLICKHOUSECONNECTOR_ADDITIONALPROPERTIESENTRY']._loaded_options = None
  _globals['_CLICKHOUSECONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_CLICKHOUSECONNECTOR'].fields_by_name['additional_properties']._loaded_options = None
  _globals['_CLICKHOUSECONNECTOR'].fields_by_name['additional_properties']._serialized_options = b'\362\3071\025[-_0-9a-zA-Z.,:\\/_ ]*\202\3101\005<=256\212\3101\005<=128\262\3101\032\022\021[a-z][-_0-9a-z.]*\032\0051-128'
  _globals['_TPCHCONNECTOR_ADDITIONALPROPERTIESENTRY']._loaded_options = None
  _globals['_TPCHCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_TPCHCONNECTOR'].fields_by_name['additional_properties']._loaded_options = None
  _globals['_TPCHCONNECTOR'].fields_by_name['additional_properties']._serialized_options = b'\362\3071\025[-_0-9a-zA-Z.,:\\/_ ]*\202\3101\005<=256\212\3101\005<=128\262\3101\032\022\021[a-z][-_0-9a-z.]*\032\0051-128'
  _globals['_TPCDSCONNECTOR_ADDITIONALPROPERTIESENTRY']._loaded_options = None
  _globals['_TPCDSCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_TPCDSCONNECTOR'].fields_by_name['additional_properties']._loaded_options = None
  _globals['_TPCDSCONNECTOR'].fields_by_name['additional_properties']._serialized_options = b'\362\3071\025[-_0-9a-zA-Z.,:\\/_ ]*\202\3101\005<=256\212\3101\005<=128\262\3101\032\022\021[a-z][-_0-9a-z.]*\032\0051-128'
  _globals['_ORACLECONNECTION_ONPREMISE'].fields_by_name['connection_url']._loaded_options = None
  _globals['_ORACLECONNECTION_ONPREMISE'].fields_by_name['connection_url']._serialized_options = b'\350\3071\001\362\3071\025^jdbc:oracle:(?s:.*)$'
  _globals['_ORACLECONNECTION_ONPREMISE'].fields_by_name['user_name']._loaded_options = None
  _globals['_ORACLECONNECTION_ONPREMISE'].fields_by_name['user_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_ORACLECONNECTION_ONPREMISE'].fields_by_name['password']._loaded_options = None
  _globals['_ORACLECONNECTION_ONPREMISE'].fields_by_name['password']._serialized_options = b'\350\3071\001\212\3101\0050-128'
  _globals['_ORACLECONNECTION'].oneofs_by_name['type']._loaded_options = None
  _globals['_ORACLECONNECTION'].oneofs_by_name['type']._serialized_options = b'\300\3011\001'
  _globals['_ORACLECONNECTOR_ADDITIONALPROPERTIESENTRY']._loaded_options = None
  _globals['_ORACLECONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_ORACLECONNECTOR'].fields_by_name['additional_properties']._loaded_options = None
  _globals['_ORACLECONNECTOR'].fields_by_name['additional_properties']._serialized_options = b'\362\3071\025[-_0-9a-zA-Z.,:\\/_ ]*\202\3101\005<=256\212\3101\005<=128\262\3101\032\022\021[a-z][-_0-9a-z.]*\032\0051-128'
  _globals['_SQLSERVERCONNECTION_ONPREMISE'].fields_by_name['connection_url']._loaded_options = None
  _globals['_SQLSERVERCONNECTION_ONPREMISE'].fields_by_name['connection_url']._serialized_options = b'\350\3071\001\362\3071\030^jdbc:sqlserver:(?s:.*)$'
  _globals['_SQLSERVERCONNECTION_ONPREMISE'].fields_by_name['user_name']._loaded_options = None
  _globals['_SQLSERVERCONNECTION_ONPREMISE'].fields_by_name['user_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_SQLSERVERCONNECTION_ONPREMISE'].fields_by_name['password']._loaded_options = None
  _globals['_SQLSERVERCONNECTION_ONPREMISE'].fields_by_name['password']._serialized_options = b'\350\3071\001\212\3101\0050-128'
  _globals['_SQLSERVERCONNECTION'].oneofs_by_name['type']._loaded_options = None
  _globals['_SQLSERVERCONNECTION'].oneofs_by_name['type']._serialized_options = b'\300\3011\001'
  _globals['_SQLSERVERCONNECTOR_ADDITIONALPROPERTIESENTRY']._loaded_options = None
  _globals['_SQLSERVERCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_SQLSERVERCONNECTOR'].fields_by_name['additional_properties']._loaded_options = None
  _globals['_SQLSERVERCONNECTOR'].fields_by_name['additional_properties']._serialized_options = b'\362\3071\025[-_0-9a-zA-Z.,:\\/_ ]*\202\3101\005<=256\212\3101\005<=128\262\3101\032\022\021[a-z][-_0-9a-z.]*\032\0051-128'
  _globals['_MYSQLCONNECTION_ONPREMISE'].fields_by_name['connection_url']._loaded_options = None
  _globals['_MYSQLCONNECTION_ONPREMISE'].fields_by_name['connection_url']._serialized_options = b'\350\3071\001\362\3071!^jdbc:mysql://(?:.+:\\d+)(?:/?.*)$'
  _globals['_MYSQLCONNECTION_ONPREMISE'].fields_by_name['user_name']._loaded_options = None
  _globals['_MYSQLCONNECTION_ONPREMISE'].fields_by_name['user_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_MYSQLCONNECTION_ONPREMISE'].fields_by_name['password']._loaded_options = None
  _globals['_MYSQLCONNECTION_ONPREMISE'].fields_by_name['password']._serialized_options = b'\350\3071\001\212\3101\0050-128'
  _globals['_MYSQLCONNECTION_CONNECTIONMANAGER_CONNECTIONPROPERTIESENTRY']._loaded_options = None
  _globals['_MYSQLCONNECTION_CONNECTIONMANAGER_CONNECTIONPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_MYSQLCONNECTION_CONNECTIONMANAGER'].fields_by_name['connection_id']._loaded_options = None
  _globals['_MYSQLCONNECTION_CONNECTIONMANAGER'].fields_by_name['connection_id']._serialized_options = b'\350\3071\001\212\3101\0041-50'
  _globals['_MYSQLCONNECTION_CONNECTIONMANAGER'].fields_by_name['connection_properties']._loaded_options = None
  _globals['_MYSQLCONNECTION_CONNECTIONMANAGER'].fields_by_name['connection_properties']._serialized_options = b'\362\3071\024[-_0-9a-zA-Z.,:\\/_]*\202\3101\005<=256\212\3101\005<=128\262\3101\023\022\n[a-zA-Z_]*\032\0051-128'
  _globals['_MYSQLCONNECTION'].oneofs_by_name['type']._loaded_options = None
  _globals['_MYSQLCONNECTION'].oneofs_by_name['type']._serialized_options = b'\300\3011\001'
  _globals['_MYSQLCONNECTOR_ADDITIONALPROPERTIESENTRY']._loaded_options = None
  _globals['_MYSQLCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_MYSQLCONNECTOR'].fields_by_name['additional_properties']._loaded_options = None
  _globals['_MYSQLCONNECTOR'].fields_by_name['additional_properties']._serialized_options = b'\362\3071\025[-_0-9a-zA-Z.,:\\/_ ]*\202\3101\005<=256\212\3101\005<=128\262\3101\032\022\021[a-z][-_0-9a-z.]*\032\0051-128'
  _globals['_GREENPLUMCONNECTION_ONPREMISE'].fields_by_name['connection_url']._loaded_options = None
  _globals['_GREENPLUMCONNECTION_ONPREMISE'].fields_by_name['connection_url']._serialized_options = b'\350\3071\001\362\3071%^jdbc:postgresql://(?:.+:\\d+)/(?:.*)$'
  _globals['_GREENPLUMCONNECTION_ONPREMISE'].fields_by_name['user_name']._loaded_options = None
  _globals['_GREENPLUMCONNECTION_ONPREMISE'].fields_by_name['user_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_GREENPLUMCONNECTION_ONPREMISE'].fields_by_name['password']._loaded_options = None
  _globals['_GREENPLUMCONNECTION_ONPREMISE'].fields_by_name['password']._serialized_options = b'\350\3071\001\212\3101\0050-128'
  _globals['_GREENPLUMCONNECTION_CONNECTIONMANAGER_CONNECTIONPROPERTIESENTRY']._loaded_options = None
  _globals['_GREENPLUMCONNECTION_CONNECTIONMANAGER_CONNECTIONPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_GREENPLUMCONNECTION_CONNECTIONMANAGER'].fields_by_name['connection_id']._loaded_options = None
  _globals['_GREENPLUMCONNECTION_CONNECTIONMANAGER'].fields_by_name['connection_id']._serialized_options = b'\350\3071\001\212\3101\0041-50'
  _globals['_GREENPLUMCONNECTION_CONNECTIONMANAGER'].fields_by_name['database']._loaded_options = None
  _globals['_GREENPLUMCONNECTION_CONNECTIONMANAGER'].fields_by_name['database']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_GREENPLUMCONNECTION_CONNECTIONMANAGER'].fields_by_name['connection_properties']._loaded_options = None
  _globals['_GREENPLUMCONNECTION_CONNECTIONMANAGER'].fields_by_name['connection_properties']._serialized_options = b'\362\3071\024[-_0-9a-zA-Z.,:\\/_]*\202\3101\005<=256\212\3101\005<=128\262\3101\022\022\t[a-zA-Z]*\032\0051-128'
  _globals['_GREENPLUMCONNECTION'].oneofs_by_name['type']._loaded_options = None
  _globals['_GREENPLUMCONNECTION'].oneofs_by_name['type']._serialized_options = b'\300\3011\001'
  _globals['_GREENPLUMCONNECTOR_ADDITIONALPROPERTIESENTRY']._loaded_options = None
  _globals['_GREENPLUMCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_GREENPLUMCONNECTOR'].fields_by_name['additional_properties']._loaded_options = None
  _globals['_GREENPLUMCONNECTOR'].fields_by_name['additional_properties']._serialized_options = b'\362\3071\025[-_0-9a-zA-Z.,:\\/_ ]*\202\3101\005<=256\212\3101\005<=128\262\3101\032\022\021[a-z][-_0-9a-z.]*\032\0051-128'
  _globals['_CONNECTOR']._serialized_start=94
  _globals['_CONNECTOR']._serialized_end=836
  _globals['_CATALOG']._serialized_start=839
  _globals['_CATALOG']._serialized_end=1055
  _globals['_CATALOG_LABELSENTRY']._serialized_start=1010
  _globals['_CATALOG_LABELSENTRY']._serialized_end=1055
  _globals['_CATALOGSPEC']._serialized_start=1058
  _globals['_CATALOGSPEC']._serialized_end=1380
  _globals['_CATALOGSPEC_LABELSENTRY']._serialized_start=1010
  _globals['_CATALOGSPEC_LABELSENTRY']._serialized_end=1055
  _globals['_CATALOGUPDATESPEC']._serialized_start=1383
  _globals['_CATALOGUPDATESPEC']._serialized_end=1708
  _globals['_CATALOGUPDATESPEC_LABELSENTRY']._serialized_start=1010
  _globals['_CATALOGUPDATESPEC_LABELSENTRY']._serialized_end=1055
  _globals['_METASTORE']._serialized_start=1711
  _globals['_METASTORE']._serialized_end=1852
  _globals['_METASTORE_HIVEMETASTORE']._serialized_start=1788
  _globals['_METASTORE_HIVEMETASTORE']._serialized_end=1838
  _globals['_FILESYSTEM']._serialized_start=1855
  _globals['_FILESYSTEM']._serialized_end=2177
  _globals['_FILESYSTEM_S3FILESYSTEM']._serialized_start=2010
  _globals['_FILESYSTEM_S3FILESYSTEM']._serialized_end=2024
  _globals['_FILESYSTEM_EXTERNALS3FILESYSTEM']._serialized_start=2027
  _globals['_FILESYSTEM_EXTERNALS3FILESYSTEM']._serialized_end=2163
  _globals['_HIVECONNECTOR']._serialized_start=2180
  _globals['_HIVECONNECTOR']._serialized_end=2547
  _globals['_HIVECONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_start=2488
  _globals['_HIVECONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_end=2547
  _globals['_ICEBERGCONNECTOR']._serialized_start=2550
  _globals['_ICEBERGCONNECTOR']._serialized_end=2923
  _globals['_ICEBERGCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_start=2488
  _globals['_ICEBERGCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_end=2547
  _globals['_DELTALAKECONNECTOR']._serialized_start=2926
  _globals['_DELTALAKECONNECTOR']._serialized_end=3303
  _globals['_DELTALAKECONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_start=2488
  _globals['_DELTALAKECONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_end=2547
  _globals['_HUDICONNECTOR']._serialized_start=3306
  _globals['_HUDICONNECTOR']._serialized_end=3673
  _globals['_HUDICONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_start=2488
  _globals['_HUDICONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_end=2547
  _globals['_POSTGRESQLCONNECTION']._serialized_start=3676
  _globals['_POSTGRESQLCONNECTION']._serialized_end=4408
  _globals['_POSTGRESQLCONNECTION_ONPREMISE']._serialized_start=3871
  _globals['_POSTGRESQLCONNECTION_ONPREMISE']._serialized_end=4037
  _globals['_POSTGRESQLCONNECTION_CONNECTIONMANAGER']._serialized_start=4040
  _globals['_POSTGRESQLCONNECTION_CONNECTIONMANAGER']._serialized_end=4394
  _globals['_POSTGRESQLCONNECTION_CONNECTIONMANAGER_CONNECTIONPROPERTIESENTRY']._serialized_start=4335
  _globals['_POSTGRESQLCONNECTION_CONNECTIONMANAGER_CONNECTIONPROPERTIESENTRY']._serialized_end=4394
  _globals['_POSTGRESQLCONNECTOR']._serialized_start=4411
  _globals['_POSTGRESQLCONNECTOR']._serialized_end=4735
  _globals['_POSTGRESQLCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_start=2488
  _globals['_POSTGRESQLCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_end=2547
  _globals['_CLICKHOUSECONNECTION']._serialized_start=4738
  _globals['_CLICKHOUSECONNECTION']._serialized_end=5471
  _globals['_CLICKHOUSECONNECTION_ONPREMISE']._serialized_start=4933
  _globals['_CLICKHOUSECONNECTION_ONPREMISE']._serialized_end=5099
  _globals['_CLICKHOUSECONNECTION_CONNECTIONMANAGER']._serialized_start=5102
  _globals['_CLICKHOUSECONNECTION_CONNECTIONMANAGER']._serialized_end=5457
  _globals['_CLICKHOUSECONNECTION_CONNECTIONMANAGER_CONNECTIONPROPERTIESENTRY']._serialized_start=4335
  _globals['_CLICKHOUSECONNECTION_CONNECTIONMANAGER_CONNECTIONPROPERTIESENTRY']._serialized_end=4394
  _globals['_CLICKHOUSECONNECTOR']._serialized_start=5474
  _globals['_CLICKHOUSECONNECTOR']._serialized_end=5798
  _globals['_CLICKHOUSECONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_start=2488
  _globals['_CLICKHOUSECONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_end=2547
  _globals['_TPCHCONNECTOR']._serialized_start=5801
  _globals['_TPCHCONNECTOR']._serialized_end=6048
  _globals['_TPCHCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_start=2488
  _globals['_TPCHCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_end=2547
  _globals['_TPCDSCONNECTOR']._serialized_start=6051
  _globals['_TPCDSCONNECTOR']._serialized_end=6300
  _globals['_TPCDSCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_start=2488
  _globals['_TPCDSCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_end=2547
  _globals['_ORACLECONNECTION']._serialized_start=6303
  _globals['_ORACLECONNECTION']._serialized_end=6561
  _globals['_ORACLECONNECTION_ONPREMISE']._serialized_start=6397
  _globals['_ORACLECONNECTION_ONPREMISE']._serialized_end=6547
  _globals['_ORACLECONNECTOR']._serialized_start=6564
  _globals['_ORACLECONNECTOR']._serialized_end=6876
  _globals['_ORACLECONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_start=2488
  _globals['_ORACLECONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_end=2547
  _globals['_SQLSERVERCONNECTION']._serialized_start=6879
  _globals['_SQLSERVERCONNECTION']._serialized_end=7146
  _globals['_SQLSERVERCONNECTION_ONPREMISE']._serialized_start=6979
  _globals['_SQLSERVERCONNECTION_ONPREMISE']._serialized_end=7132
  _globals['_SQLSERVERCONNECTOR']._serialized_start=7149
  _globals['_SQLSERVERCONNECTOR']._serialized_end=7470
  _globals['_SQLSERVERCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_start=2488
  _globals['_SQLSERVERCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_end=2547
  _globals['_MYSQLCONNECTION']._serialized_start=7473
  _globals['_MYSQLCONNECTION']._serialized_end=8132
  _globals['_MYSQLCONNECTION_ONPREMISE']._serialized_start=7653
  _globals['_MYSQLCONNECTION_ONPREMISE']._serialized_end=7815
  _globals['_MYSQLCONNECTION_CONNECTIONMANAGER']._serialized_start=7818
  _globals['_MYSQLCONNECTION_CONNECTIONMANAGER']._serialized_end=8118
  _globals['_MYSQLCONNECTION_CONNECTIONMANAGER_CONNECTIONPROPERTIESENTRY']._serialized_start=4335
  _globals['_MYSQLCONNECTION_CONNECTIONMANAGER_CONNECTIONPROPERTIESENTRY']._serialized_end=4394
  _globals['_MYSQLCONNECTOR']._serialized_start=8135
  _globals['_MYSQLCONNECTOR']._serialized_end=8444
  _globals['_MYSQLCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_start=2488
  _globals['_MYSQLCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_end=2547
  _globals['_GREENPLUMCONNECTION']._serialized_start=8447
  _globals['_GREENPLUMCONNECTION']._serialized_end=9175
  _globals['_GREENPLUMCONNECTION_ONPREMISE']._serialized_start=3871
  _globals['_GREENPLUMCONNECTION_ONPREMISE']._serialized_end=4037
  _globals['_GREENPLUMCONNECTION_CONNECTIONMANAGER']._serialized_start=8808
  _globals['_GREENPLUMCONNECTION_CONNECTIONMANAGER']._serialized_end=9161
  _globals['_GREENPLUMCONNECTION_CONNECTIONMANAGER_CONNECTIONPROPERTIESENTRY']._serialized_start=4335
  _globals['_GREENPLUMCONNECTION_CONNECTIONMANAGER_CONNECTIONPROPERTIESENTRY']._serialized_end=4394
  _globals['_GREENPLUMCONNECTOR']._serialized_start=9178
  _globals['_GREENPLUMCONNECTOR']._serialized_end=9499
  _globals['_GREENPLUMCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_start=2488
  _globals['_GREENPLUMCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_end=2547
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ProductType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ProductTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ProductType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PRODUCT_TYPE_UNSPECIFIED: _ProductType.ValueType  # 0
    """Unspecified product type."""
    PRODUCT_TYPE_STACKLAND: _ProductType.ValueType  # 1
    """Stackland product."""
    PRODUCT_TYPE_DATALENS: _ProductType.ValueType  # 2
    """DataLens product."""
    PRODUCT_TYPE_AI_STUDIO: _ProductType.ValueType  # 3
    """AI Studio product."""
    PRODUCT_TYPE_SPEECHSENSE: _ProductType.ValueType  # 4
    """SpeechSense product."""
    PRODUCT_TYPE_ROBOTICS_AI: _ProductType.ValueType  # 5
    """Robotics AI product."""

class ProductType(_ProductType, metaclass=_ProductTypeEnumTypeWrapper):
    """Product type enum"""

PRODUCT_TYPE_UNSPECIFIED: ProductType.ValueType  # 0
"""Unspecified product type."""
PRODUCT_TYPE_STACKLAND: ProductType.ValueType  # 1
"""Stackland product."""
PRODUCT_TYPE_DATALENS: ProductType.ValueType  # 2
"""DataLens product."""
PRODUCT_TYPE_AI_STUDIO: ProductType.ValueType  # 3
"""AI Studio product."""
PRODUCT_TYPE_SPEECHSENSE: ProductType.ValueType  # 4
"""SpeechSense product."""
PRODUCT_TYPE_ROBOTICS_AI: ProductType.ValueType  # 5
"""Robotics AI product."""
global___ProductType = ProductType

class _SyncStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SyncStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SyncStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SYNC_STATUS_UNSPECIFIED: _SyncStatus.ValueType  # 0
    """Unspecified sync status."""
    OK: _SyncStatus.ValueType  # 1
    """Sync completed successfully."""
    WARNING: _SyncStatus.ValueType  # 2
    """Sync completed with warnings."""
    ERROR: _SyncStatus.ValueType  # 3
    """Sync failed with errors."""

class SyncStatus(_SyncStatus, metaclass=_SyncStatusEnumTypeWrapper):
    """Sync status enum"""

SYNC_STATUS_UNSPECIFIED: SyncStatus.ValueType  # 0
"""Unspecified sync status."""
OK: SyncStatus.ValueType  # 1
"""Sync completed successfully."""
WARNING: SyncStatus.ValueType  # 2
"""Sync completed with warnings."""
ERROR: SyncStatus.ValueType  # 3
"""Sync failed with errors."""
global___SyncStatus = SyncStatus

@typing.final
class UsageEntry(google.protobuf.message.Message):
    """Usage data entry for a single installation"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTALLATION_ID_FIELD_NUMBER: builtins.int
    PRODUCT_TYPE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    USAGE_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    HARDWARE_FINGERPRINT_FIELD_NUMBER: builtins.int
    LICENSE_ID_FIELD_NUMBER: builtins.int
    REQUESTED_VALUE_FIELD_NUMBER: builtins.int
    SERVER_TIMESTAMP_FIELD_NUMBER: builtins.int
    PREV_RECORD_HASH_FIELD_NUMBER: builtins.int
    RECORD_HASH_FIELD_NUMBER: builtins.int
    SIGNATURE_FIELD_NUMBER: builtins.int
    installation_id: builtins.str
    """Installation ID"""
    product_type: global___ProductType.ValueType
    """Product type"""
    type: builtins.str
    """Usage metric type (e.g., "stackland.vcpu.cores")"""
    usage: builtins.int
    """Usage value"""
    hardware_fingerprint: builtins.str
    """Hardware fingerprint for the installation"""
    license_id: builtins.str
    """License ID this usage applies to"""
    requested_value: builtins.int
    """Requested license limit value (optional)"""
    prev_record_hash: builtins.str
    """Previous record's hash in the chain (64 hex characters)"""
    record_hash: builtins.str
    """SHA-256 hash of this record (64 hex characters)"""
    signature: builtins.str
    """RSA-PSS signature of the record hash (base64-encoded)"""
    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp of the usage (client-side timestamp)"""

    @property
    def server_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Server-side timestamp set by license server"""

    def __init__(
        self,
        *,
        installation_id: builtins.str = ...,
        product_type: global___ProductType.ValueType = ...,
        type: builtins.str = ...,
        usage: builtins.int = ...,
        timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        hardware_fingerprint: builtins.str = ...,
        license_id: builtins.str = ...,
        requested_value: builtins.int = ...,
        server_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        prev_record_hash: builtins.str = ...,
        record_hash: builtins.str = ...,
        signature: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["server_timestamp", b"server_timestamp", "timestamp", b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["hardware_fingerprint", b"hardware_fingerprint", "installation_id", b"installation_id", "license_id", b"license_id", "prev_record_hash", b"prev_record_hash", "product_type", b"product_type", "record_hash", b"record_hash", "requested_value", b"requested_value", "server_timestamp", b"server_timestamp", "signature", b"signature", "timestamp", b"timestamp", "type", b"type", "usage", b"usage"]) -> None: ...

global___UsageEntry = UsageEntry

@typing.final
class LicenseLimit(google.protobuf.message.Message):
    """License limit for a specific metric type"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    LIMIT_FIELD_NUMBER: builtins.int
    type: builtins.str
    """Metric type (e.g., "stackland.vcpu.cores")"""
    limit: builtins.int
    """Limit value"""
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        limit: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["limit", b"limit", "type", b"type"]) -> None: ...

global___LicenseLimit = LicenseLimit

@typing.final
class License(google.protobuf.message.Message):
    """License information returned by the sync API"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LICENSE_ID_FIELD_NUMBER: builtins.int
    PRODUCT_TYPE_FIELD_NUMBER: builtins.int
    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    BILLING_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    ISSUED_AT_FIELD_NUMBER: builtins.int
    VALID_UNTIL_FIELD_NUMBER: builtins.int
    LIMITS_FIELD_NUMBER: builtins.int
    SIGNATURE_FIELD_NUMBER: builtins.int
    license_id: builtins.str
    """Unique license ID"""
    product_type: global___ProductType.ValueType
    """Product type this license applies to"""
    organization_id: builtins.str
    """Organization ID"""
    billing_account_id: builtins.str
    """Billing account ID"""
    signature: builtins.str
    """Digital signature for this license"""
    @property
    def issued_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp when the license was issued"""

    @property
    def valid_until(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp when the license expires"""

    @property
    def limits(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LicenseLimit]:
        """List of limits for this license"""

    def __init__(
        self,
        *,
        license_id: builtins.str = ...,
        product_type: global___ProductType.ValueType = ...,
        organization_id: builtins.str = ...,
        billing_account_id: builtins.str = ...,
        issued_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        valid_until: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        limits: collections.abc.Iterable[global___LicenseLimit] | None = ...,
        signature: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["issued_at", b"issued_at", "valid_until", b"valid_until"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["billing_account_id", b"billing_account_id", "issued_at", b"issued_at", "license_id", b"license_id", "limits", b"limits", "organization_id", b"organization_id", "product_type", b"product_type", "signature", b"signature", "valid_until", b"valid_until"]) -> None: ...

global___License = License

@typing.final
class SyncRequest(google.protobuf.message.Message):
    """Request to synchronize licenses and submit usage data"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    BILLING_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    LICENSE_SERVER_ID_FIELD_NUMBER: builtins.int
    USAGE_FIELD_NUMBER: builtins.int
    organization_id: builtins.str
    """Organization ID"""
    billing_account_id: builtins.str
    """Billing account ID"""
    license_server_id: builtins.str
    """License server ID"""
    @property
    def usage(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UsageEntry]:
        """Usage data for audit"""

    def __init__(
        self,
        *,
        organization_id: builtins.str = ...,
        billing_account_id: builtins.str = ...,
        license_server_id: builtins.str = ...,
        usage: collections.abc.Iterable[global___UsageEntry] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["billing_account_id", b"billing_account_id", "license_server_id", b"license_server_id", "organization_id", b"organization_id", "usage", b"usage"]) -> None: ...

global___SyncRequest = SyncRequest

@typing.final
class SyncUsageResult(google.protobuf.message.Message):
    """Result of the sync operation"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LICENSES_FIELD_NUMBER: builtins.int
    SYNC_STATUS_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    sync_status: global___SyncStatus.ValueType
    """Overall sync status"""
    message: builtins.str
    """Optional message (e.g., warnings or errors)"""
    @property
    def licenses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___License]:
        """List of licenses for different product types"""

    def __init__(
        self,
        *,
        licenses: collections.abc.Iterable[global___License] | None = ...,
        sync_status: global___SyncStatus.ValueType = ...,
        message: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["licenses", b"licenses", "message", b"message", "sync_status", b"sync_status"]) -> None: ...

global___SyncUsageResult = SyncUsageResult

@typing.final
class SyncUsageMetadata(google.protobuf.message.Message):
    """Metadata for sync operation"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    BILLING_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    LICENSE_SERVER_ID_FIELD_NUMBER: builtins.int
    organization_id: builtins.str
    """Organization ID"""
    billing_account_id: builtins.str
    """Billing account ID"""
    license_server_id: builtins.str
    """License server ID"""
    def __init__(
        self,
        *,
        organization_id: builtins.str = ...,
        billing_account_id: builtins.str = ...,
        license_server_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["billing_account_id", b"billing_account_id", "license_server_id", b"license_server_id", "organization_id", b"organization_id"]) -> None: ...

global___SyncUsageMetadata = SyncUsageMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import yandex.cloud.billing.usage_records.v1.billing_types_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetUsageRequest(google.protobuf.message.Message):
    """GetUsageRequest request for retrieving usage metadata"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BILLING_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    START_DATE_FIELD_NUMBER: builtins.int
    END_DATE_FIELD_NUMBER: builtins.int
    billing_account_id: builtins.str
    """Required. Billing account identifier.
    The ID of the billing account to retrieve usage metadata for.
    Must be a valid and accessible billing account ID.
    """
    @property
    def start_date(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Start date for data retrieval.
        The inclusive start of the date range for which to retrieve usage metadata.
        Must be specified and cannot be empty.
        The time portion is ignored; the date is considered to start at 00:00:00.
        """

    @property
    def end_date(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """End date for data retrieval.
        The inclusive end of the date range for which to retrieve usage metadata.
        Must be specified, cannot be empty, and must be greater than or equal to start_date.
        The time portion is ignored; the date is considered to end at 23:59:59.
        """

    def __init__(
        self,
        *,
        billing_account_id: builtins.str = ...,
        start_date: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        end_date: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["end_date", b"end_date", "start_date", b"start_date"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["billing_account_id", b"billing_account_id", "end_date", b"end_date", "start_date", b"start_date"]) -> None: ...

global___GetUsageRequest = GetUsageRequest

@typing.final
class GetUsageResponse(google.protobuf.message.Message):
    """Response for usage metadata request"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLOUDS_FIELD_NUMBER: builtins.int
    LABEL_KEYS_FIELD_NUMBER: builtins.int
    SERVICES_FIELD_NUMBER: builtins.int
    SKUS_FIELD_NUMBER: builtins.int
    BILLING_ACCOUNTS_FIELD_NUMBER: builtins.int
    @property
    def clouds(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.billing.usage_records.v1.billing_types_pb2.Cloud]:
        """List of available clouds for the current user/context (billing_account_id with sub-accounts)
        Contains cloud entities that the user has access to within the specified date range.

        Note: Empty cloud_id values are considered as "consumption outside the cloud"
        and represented with an empty string id and name "Usage is out of scope of the Cloud"
        """

    @property
    def label_keys(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of available label keys for the current user/context (billing_account_id with sub-accounts)
        Contains all label keys that exist in usage records
        within the specified date range.
        These keys can be used for filtering and grouping in reports or
        passed to the GetLabel method to retrieve possible values.
        """

    @property
    def services(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.billing.usage_records.v1.billing_types_pb2.Service]:
        """List of available services for the current user/context (billing_account_id with sub-accounts)
        Contains service entities with their IDs, names and descriptions that
        have usage records within the specified billing account and date range.
        Services represent the top-level grouping of cloud offerings.
        """

    @property
    def skus(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.billing.usage_records.v1.billing_types_pb2.SKU]:
        """List of available SKUs for the current user/context (billing_account_id with sub-accounts)
        Contains SKU entities with their IDs, names, translations and pricing units
        that have usage records within the specified billing account and date range.
        SKUs represent specific service offerings
        """

    @property
    def billing_accounts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.billing.usage_records.v1.billing_types_pb2.BillingAccount]:
        """List of available BillingAccounts for the current user/context (billing_account_id with sub-accounts)
        Contains billing account entities that the user has access to and
        that have usage records within the specified date range.
        Includes both the main account and any sub-accounts.
        """

    def __init__(
        self,
        *,
        clouds: collections.abc.Iterable[yandex.cloud.billing.usage_records.v1.billing_types_pb2.Cloud] | None = ...,
        label_keys: collections.abc.Iterable[builtins.str] | None = ...,
        services: collections.abc.Iterable[yandex.cloud.billing.usage_records.v1.billing_types_pb2.Service] | None = ...,
        skus: collections.abc.Iterable[yandex.cloud.billing.usage_records.v1.billing_types_pb2.SKU] | None = ...,
        billing_accounts: collections.abc.Iterable[yandex.cloud.billing.usage_records.v1.billing_types_pb2.BillingAccount] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["billing_accounts", b"billing_accounts", "clouds", b"clouds", "label_keys", b"label_keys", "services", b"services", "skus", b"skus"]) -> None: ...

global___GetUsageResponse = GetUsageResponse

@typing.final
class GetLabelRequest(google.protobuf.message.Message):
    """Request for retrieving label metadata"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BILLING_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    START_DATE_FIELD_NUMBER: builtins.int
    END_DATE_FIELD_NUMBER: builtins.int
    LABEL_KEY_FIELD_NUMBER: builtins.int
    LABEL_VALUE_FIELD_NUMBER: builtins.int
    LABEL_VALUE_FILTER_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    billing_account_id: builtins.str
    """Required. Billing account identifier.
    The ID of the billing account to retrieve label metadata for.
    Must be a valid and accessible billing account ID.
    """
    label_key: builtins.str
    """Label key to filter values for. If specified, response will contain values
    for this specific key.
    Must be a non-empty string representing a valid label key.
    """
    label_value: builtins.str
    """Optional. If provided along with label_key, the response will return
    an array of matches for this label_value.
    Used for exact matching of label values.
    If specified, label_value_filter is ignored and pagination is not applied.
    """
    page_size: builtins.int
    """Optional. Page size for paginated results.
    Specifies the maximum number of label values to return per page.
    If not specified or set to 0, defaults to 10.
    If greater than 10000, will be coerced down to 10000.
    """
    page_token: builtins.str
    """Optional. Page token for paginated results.
    Token from a previous GetLabelResponse used to retrieve the next page.
    If empty, retrieves the first page.
    """
    @property
    def start_date(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Start date for data retrieval.
        The inclusive start of the date range for which to retrieve label metadata.
        Must be specified and cannot be empty.
        The time portion is ignored; the date is considered to start at 00:00:00.
        """

    @property
    def end_date(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """End date for data retrieval.
        The inclusive end of the date range for which to retrieve label metadata.
        Must be specified, cannot be empty, and must be greater than or equal to start_date.
        The time portion is ignored; the date is considered to end at 23:59:59.
        """

    @property
    def label_value_filter(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Optional array of label values to filter results:
        Returns in response as is if label_value is not provided, otherwise returns empty label_value_filter
        """

    def __init__(
        self,
        *,
        billing_account_id: builtins.str = ...,
        start_date: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        end_date: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        label_key: builtins.str = ...,
        label_value: builtins.str = ...,
        label_value_filter: collections.abc.Iterable[builtins.str] | None = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["end_date", b"end_date", "start_date", b"start_date"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["billing_account_id", b"billing_account_id", "end_date", b"end_date", "label_key", b"label_key", "label_value", b"label_value", "label_value_filter", b"label_value_filter", "page_size", b"page_size", "page_token", b"page_token", "start_date", b"start_date"]) -> None: ...

global___GetLabelRequest = GetLabelRequest

@typing.final
class GetLabelResponse(google.protobuf.message.Message):
    """Response for label metadata request"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LABEL_VALUES_FIELD_NUMBER: builtins.int
    LABEL_VALUE_FILTER_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of results.
    If empty, there are no more results.
    Use this token in a subsequent request's page_token field to retrieve
    the next page of results.
    The token encodes the pagination state.

    It should be passed verbatim in subsequent requests.
    """
    @property
    def label_values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of label values matching the request criteria
        Contains label values that match the specified label key pattern.
        Values are sorted alphabetically.
        """

    @property
    def label_value_filter(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of label values from the label_value_filter in the request
        Contains the same values as provided in the request's label_value_filter.
        Included for convenience in the response.
        This field is only populated when label_value_filter was specified in the request
        and label_value was not specified.
        """

    def __init__(
        self,
        *,
        label_values: collections.abc.Iterable[builtins.str] | None = ...,
        label_value_filter: collections.abc.Iterable[builtins.str] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["label_value_filter", b"label_value_filter", "label_values", b"label_values", "next_page_token", b"next_page_token"]) -> None: ...

global___GetLabelResponse = GetLabelResponse

@typing.final
class GetCloudRequest(google.protobuf.message.Message):
    """Request for retrieving folder metadata"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BILLING_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    START_DATE_FIELD_NUMBER: builtins.int
    END_DATE_FIELD_NUMBER: builtins.int
    CLOUD_IDS_FIELD_NUMBER: builtins.int
    FOLDER_IDS_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    billing_account_id: builtins.str
    """Required. Billing account identifier.
    The ID of the billing account to retrieve cloud and folder metadata for.
    Must be a valid and accessible billing account ID.
    """
    page_size: builtins.int
    """Optional. Page size for paginated results.
    Specifies the maximum number of Folder objects to return per page.
    If not specified or set to 0, defaults to 10.
    If greater than 10000, will be coerced down to 10000.
    """
    page_token: builtins.str
    """Optional. Page token for paginated results.
    Token from a previous GetCloudResponse used to retrieve the next page.
    If empty, retrieves the first page.
    The token encodes the pagination state.
    """
    @property
    def start_date(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Start date for data retrieval.
        The inclusive start of the date range for which to retrieve cloud and folder metadata.
        Must be specified and cannot be empty.
        The time portion is ignored; the date is considered to start at 00:00:00.
        """

    @property
    def end_date(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """End date for data retrieval.
        The inclusive end of the date range for which to retrieve cloud and folder metadata.
        Must be specified, cannot be empty, and must be greater than or equal to start_date.
        The time portion is ignored; the date is considered to end at 23:59:59.
        """

    @property
    def cloud_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Optional. List of cloud IDs to filter clouds by.
        Note: cloud_id filtering supports case-insensitive substring matching.
        No wildcards or regex patterns are supported - just simple substring matching.
        The filter works with partial cloud IDs, and will match any cloud where
        the provided substring appears anywhere in the cloud_id.
        For example, filter "abc" will match cloud_ids like "abc123", "123abc", or "1abc2".
        If empty, no filtering by cloud ID is applied.
        """

    @property
    def folder_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Optional. List of folder IDs to filter folders by.
        Note: folder_id filtering supports case-insensitive substring matching.
        No wildcards or regex patterns are supported - just simple substring matching.
        The filter works with partial folder IDs, and will match any folder where
        the provided substring appears anywhere in the folder_id.
        For example, filter "abc" will match folder_ids like "abc123", "123abc", or "1abc2".
        If empty, no filtering by folder ID is applied.
        """

    def __init__(
        self,
        *,
        billing_account_id: builtins.str = ...,
        start_date: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        end_date: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        cloud_ids: collections.abc.Iterable[builtins.str] | None = ...,
        folder_ids: collections.abc.Iterable[builtins.str] | None = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["end_date", b"end_date", "start_date", b"start_date"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["billing_account_id", b"billing_account_id", "cloud_ids", b"cloud_ids", "end_date", b"end_date", "folder_ids", b"folder_ids", "page_size", b"page_size", "page_token", b"page_token", "start_date", b"start_date"]) -> None: ...

global___GetCloudRequest = GetCloudRequest

@typing.final
class GetCloudResponse(google.protobuf.message.Message):
    """Response for cloud metadata request"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class CloudInfo(google.protobuf.message.Message):
        """Information about a cloud and its folders"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CLOUD_FIELD_NUMBER: builtins.int
        FOLDERS_FIELD_NUMBER: builtins.int
        @property
        def cloud(self) -> yandex.cloud.billing.usage_records.v1.billing_types_pb2.Cloud:
            """Cloud information"""

        @property
        def folders(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.billing.usage_records.v1.billing_types_pb2.Folder]:
            """List of folders belonging to this cloud
            Contains folder entities that belong to this cloud
            and match any folder ID filtering criteria from the request.
            The list is sorted by folder ID in ascending order.

            Only folders that had usage during the specified date range are included.
            """

        def __init__(
            self,
            *,
            cloud: yandex.cloud.billing.usage_records.v1.billing_types_pb2.Cloud | None = ...,
            folders: collections.abc.Iterable[yandex.cloud.billing.usage_records.v1.billing_types_pb2.Folder] | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["cloud", b"cloud"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["cloud", b"cloud", "folders", b"folders"]) -> None: ...

    ITEMS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of results.
    If empty, there are no more results.
    Use this token in a subsequent request's page_token field to retrieve
    the next page of results.
    The token encodes the pagination state.

    It should be passed verbatim in subsequent requests.
    """
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GetCloudResponse.CloudInfo]:
        """List of clouds matching the request criteria
        Contains CloudInfo objects for each cloud that matches the specified
        filtering criteria

        Note: only clouds with at least one folder are included in the response.
        """

    def __init__(
        self,
        *,
        items: collections.abc.Iterable[global___GetCloudResponse.CloudInfo] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["items", b"items", "next_page_token", b"next_page_token"]) -> None: ...

global___GetCloudResponse = GetCloudResponse

@typing.final
class GetResourceIDsRequest(google.protobuf.message.Message):
    """GetResourceIDsRequest request for retrieving resource IDs.
    This message defines the parameters needed to fetch and filter resource IDs
    associated with a billing account within a date range.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BILLING_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    START_DATE_FIELD_NUMBER: builtins.int
    END_DATE_FIELD_NUMBER: builtins.int
    RESOURCE_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    billing_account_id: builtins.str
    """Required. Billing account identifier.
    The ID of the billing account to retrieve resource IDs for.
    Must be a valid and accessible billing account ID.
    """
    resource_id: builtins.str
    """Optional. Resource ID pattern for search filtering.
    When provided, the response will include only resource IDs
    that contain this string (case-insensitive substring match).
    No wildcards or regex patterns are supported - just simple substring matching.
    """
    page_size: builtins.int
    """Optional. Page size for paginated results.
    Specifies the maximum number of resource IDs to return per page.
    If not specified or set to 0, defaults to 10.
    If greater than 10000, will be coerced down to 10000.
    """
    page_token: builtins.str
    """Optional. Page token for paginated results.
    Token from a previous GetResourceIDsResponse used to retrieve the next page.
    If empty, retrieves the first page.
    The token encodes the pagination state.
    """
    @property
    def start_date(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Start date for data retrieval.
        The inclusive start of the date range for which to retrieve resource IDs.
        Must be specified and cannot be empty.
        The time portion is ignored; the date is considered to start at 00:00:00.
        """

    @property
    def end_date(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """End date for data retrieval.
        The inclusive end of the date range for which to retrieve resource IDs.
        Must be specified, cannot be empty, and must be greater than or equal to start_date.
        The time portion is ignored; the date is considered to end at 23:59:59.
        """

    def __init__(
        self,
        *,
        billing_account_id: builtins.str = ...,
        start_date: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        end_date: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        resource_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["end_date", b"end_date", "start_date", b"start_date"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["billing_account_id", b"billing_account_id", "end_date", b"end_date", "page_size", b"page_size", "page_token", b"page_token", "resource_id", b"resource_id", "start_date", b"start_date"]) -> None: ...

global___GetResourceIDsRequest = GetResourceIDsRequest

@typing.final
class GetResourceIDsResponse(google.protobuf.message.Message):
    """Response for resource IDs request.
    This message contains a list of resource IDs that match the search criteria
    specified in the request, along with pagination information.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_IDS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of results.
    This token should be passed in the page_token field of subsequent requests.
    If empty, there are no more results available.
    The token encodes the pagination state.

    It should be passed verbatim in subsequent requests.
    """
    @property
    def resource_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of resource IDs matching the request criteria.
        These represent unique identifiers for resources within the billing account
        that had usage during the specified date range.
        If a resource_id filter was provided in the request, only IDs
        containing that substring (case-insensitive) will be included.
        Resource IDs are sorted alphabetically in ascending order.
        """

    def __init__(
        self,
        *,
        resource_ids: collections.abc.Iterable[builtins.str] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "resource_ids", b"resource_ids"]) -> None: ...

global___GetResourceIDsResponse = GetResourceIDsResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/greenplum/v1/config.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/greenplum/v1/config.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*yandex/cloud/mdb/greenplum/v1/config.proto\x12\x1dyandex.cloud.mdb.greenplum.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"P\n\tResources\x12\x1a\n\x12resource_preset_id\x18\x01 \x01(\t\x12\x11\n\tdisk_size\x18\x02 \x01(\x03\x12\x14\n\x0c\x64isk_type_id\x18\x03 \x01(\t\"\xd2\x02\n\x16\x43onnectionPoolerConfig\x12L\n\x04mode\x18\x01 \x01(\x0e\x32>.yandex.cloud.mdb.greenplum.v1.ConnectionPoolerConfig.PoolMode\x12)\n\x04size\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x38\n\x13\x63lient_idle_timeout\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12@\n\x1bidle_in_transaction_timeout\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"C\n\x08PoolMode\x12\x19\n\x15POOL_MODE_UNSPECIFIED\x10\x00\x12\x0b\n\x07SESSION\x10\x01\x12\x0f\n\x0bTRANSACTION\x10\x02\"O\n\x19\x42\x61\x63kgroundActivityStartAt\x12\x17\n\x05hours\x18\x01 \x01(\x03\x42\x08\xfa\xc7\x31\x04\x30-23\x12\x19\n\x07minutes\x18\x02 \x01(\x03\x42\x08\xfa\xc7\x31\x04\x30-59\"_\n\nTableSizes\x12Q\n\x06starts\x18\x01 \x03(\x0b\x32\x38.yandex.cloud.mdb.greenplum.v1.BackgroundActivityStartAtB\x07\x82\xc8\x31\x03<=4\"\xe6\x01\n\x10\x41nalyzeAndVacuum\x12G\n\x05start\x18\x01 \x01(\x0b\x32\x38.yandex.cloud.mdb.greenplum.v1.BackgroundActivityStartAt\x12\x44\n\x0f\x61nalyze_timeout\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0e\xfa\xc7\x31\n7200-86399\x12\x43\n\x0evacuum_timeout\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0e\xfa\xc7\x31\n7200-86399\"\xfa\x01\n\x1a\x42\x61\x63kgroundActivitiesConfig\x12>\n\x0btable_sizes\x18\x01 \x01(\x0b\x32).yandex.cloud.mdb.greenplum.v1.TableSizes\x12K\n\x12\x61nalyze_and_vacuum\x18\x02 \x01(\x0b\x32/.yandex.cloud.mdb.greenplum.v1.AnalyzeAndVacuum\x12O\n\x14query_killer_scripts\x18\x03 \x01(\x0b\x32\x31.yandex.cloud.mdb.greenplum.v1.QueryKillerScripts\"\x8a\x01\n\x0bQueryKiller\x12*\n\x06\x65nable\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x39\n\x07max_age\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0b\xfa\xc7\x31\x07\x31-86400\x12\x14\n\x0cignore_users\x18\x03 \x03(\t\"\xd9\x01\n\x12QueryKillerScripts\x12\x38\n\x04idle\x18\x01 \x01(\x0b\x32*.yandex.cloud.mdb.greenplum.v1.QueryKiller\x12G\n\x13idle_in_transaction\x18\x02 \x01(\x0b\x32*.yandex.cloud.mdb.greenplum.v1.QueryKiller\x12@\n\x0clong_running\x18\x03 \x01(\x0b\x32*.yandex.cloud.mdb.greenplum.v1.QueryKiller\"U\n\x16MasterSubclusterConfig\x12;\n\tresources\x18\x01 \x01(\x0b\x32(.yandex.cloud.mdb.greenplum.v1.Resources\"V\n\x17SegmentSubclusterConfig\x12;\n\tresources\x18\x01 \x01(\x0b\x32(.yandex.cloud.mdb.greenplum.v1.Resources\"\xbe\x13\n\x10GreenplumConfig6\x12\x41\n\x0fmax_connections\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0b\xfa\xc7\x31\x07\x35\x30-1000\x12O\n\x16max_slot_wal_keep_size\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x12\xfa\xc7\x31\x0e\x30-214748364800\x12K\n\x1dgp_workfile_limit_per_segment\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12U\n\x1bgp_workfile_limit_per_query\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x13\xfa\xc7\x31\x0f\x30-1099511627776\x12T\n!gp_workfile_limit_files_per_query\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x30-100000\x12L\n\x19max_prepared_transactions\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x35\x30-10000\x12;\n\x17gp_workfile_compression\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12S\n\x11max_statement_mem\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x1b\xfa\xc7\x31\x17\x31\x33\x34\x32\x31\x37\x37\x32\x38-1099511627776\x12\x42\n\rlog_statement\x18\t \x01(\x0e\x32+.yandex.cloud.mdb.greenplum.v1.LogStatement\x12H\n$gp_add_column_inherits_table_setting\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x46\n\"gp_enable_global_deadlock_detector\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12G\n\"gp_global_deadlock_detector_period\x18\x0c \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12>\n\rgp_max_slices\x18\r \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x31\x30-100\x12M\n\x1egp_cached_segworkers_threshold\x18\x0e \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x08\xfa\xc7\x31\x04\x30-10\x12\x43\n\x0clock_timeout\x18\x0f \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x10\xfa\xc7\x31\x0c\x30-2147483647\x12Z\n#idle_in_transaction_session_timeout\x18\x10 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x10\xfa\xc7\x31\x0c\x30-2147483647\x12S\n#runaway_detector_activation_percent\x18\x11 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\t\xfa\xc7\x31\x05\x30-100\x12V\n%gp_vmem_protect_segworker_cache_limit\x18\x12 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x30-4096\x12\x44\n gp_enable_zstd_memory_accounting\x18\x13 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12G\n\x10gp_max_plan_size\x18\x14 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x10\xfa\xc7\x31\x0c\x30-2147483647\x12I\n\x11gp_autostats_mode\x18\x15 \x01(\x0e\x32..yandex.cloud.mdb.greenplum.v1.GPAutostatsMode\x12W\n gp_autostats_on_change_threshold\x18\x16 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x10\xfa\xc7\x31\x0c\x30-2147483647\x12Q\n\x1egp_resource_group_memory_limit\x18\x17 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\x0b\xfa\xc7\x31\x07\x30.1-0.8\x12\x33\n\x0flog_connections\x18\x18 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x12log_disconnections\x18\x19 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x30\n\x0clog_hostname\x18\x1a \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x37\n\x13log_statement_stats\x18\x1b \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12R\n\x1alog_min_duration_statement\x18\x1c \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x11\xfa\xc7\x31\r-1-2147483647\x12R\n\x15master_shared_buffers\x18\x1d \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x16\xfa\xc7\x31\x12\x31\x30\x34\x38\x35\x37\x36-2147483647\x12L\n\x19max_locks_per_transaction\x18\x1e \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x31\x32\x38-2048\x12S\n\x16segment_shared_buffers\x18\x1f \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x16\xfa\xc7\x31\x12\x31\x30\x34\x38\x35\x37\x36-2147483647\x12M\n\x13log_error_verbosity\x18  \x01(\x0e\x32\x30.yandex.cloud.mdb.greenplum.v1.LogErrorVerbosity\x12H\n\x10log_min_messages\x18! \x01(\x0e\x32..yandex.cloud.mdb.greenplum.v1.LogLevelMessage\"\xf7\x12\n\x13GreenplumConfigCBDB\x12\x41\n\x0fmax_connections\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0b\xfa\xc7\x31\x07\x35\x30-1000\x12O\n\x16max_slot_wal_keep_size\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x12\xfa\xc7\x31\x0e\x30-214748364800\x12K\n\x1dgp_workfile_limit_per_segment\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12U\n\x1bgp_workfile_limit_per_query\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x13\xfa\xc7\x31\x0f\x30-1099511627776\x12T\n!gp_workfile_limit_files_per_query\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x30-100000\x12L\n\x19max_prepared_transactions\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x35\x30-10000\x12;\n\x17gp_workfile_compression\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12S\n\x11max_statement_mem\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x1b\xfa\xc7\x31\x17\x31\x33\x34\x32\x31\x37\x37\x32\x38-1099511627776\x12\x42\n\rlog_statement\x18\t \x01(\x0e\x32+.yandex.cloud.mdb.greenplum.v1.LogStatement\x12\x46\n\"gp_enable_global_deadlock_detector\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12G\n\"gp_global_deadlock_detector_period\x18\x0b \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12>\n\rgp_max_slices\x18\x0c \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x31\x30-100\x12M\n\x1egp_cached_segworkers_threshold\x18\r \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x08\xfa\xc7\x31\x04\x30-10\x12\x43\n\x0clock_timeout\x18\x0e \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x10\xfa\xc7\x31\x0c\x30-2147483647\x12Z\n#idle_in_transaction_session_timeout\x18\x0f \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x10\xfa\xc7\x31\x0c\x30-2147483647\x12S\n#runaway_detector_activation_percent\x18\x10 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\t\xfa\xc7\x31\x05\x30-100\x12V\n%gp_vmem_protect_segworker_cache_limit\x18\x11 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x30-4096\x12\x44\n gp_enable_zstd_memory_accounting\x18\x12 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12G\n\x10gp_max_plan_size\x18\x13 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x10\xfa\xc7\x31\x0c\x30-2147483647\x12I\n\x11gp_autostats_mode\x18\x14 \x01(\x0e\x32..yandex.cloud.mdb.greenplum.v1.GPAutostatsMode\x12W\n gp_autostats_on_change_threshold\x18\x15 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x10\xfa\xc7\x31\x0c\x30-2147483647\x12Q\n\x1egp_resource_group_memory_limit\x18\x16 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\x0b\xfa\xc7\x31\x07\x30.1-0.8\x12\x33\n\x0flog_connections\x18\x17 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x12log_disconnections\x18\x18 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x30\n\x0clog_hostname\x18\x19 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x37\n\x13log_statement_stats\x18\x1a \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12R\n\x1alog_min_duration_statement\x18\x1b \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x11\xfa\xc7\x31\r-1-2147483647\x12R\n\x15master_shared_buffers\x18\x1c \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x16\xfa\xc7\x31\x12\x31\x30\x34\x38\x35\x37\x36-2147483647\x12L\n\x19max_locks_per_transaction\x18\x1d \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x31\x32\x38-2048\x12S\n\x16segment_shared_buffers\x18\x1e \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x16\xfa\xc7\x31\x12\x31\x30\x34\x38\x35\x37\x36-2147483647\x12M\n\x13log_error_verbosity\x18\x1f \x01(\x0e\x32\x30.yandex.cloud.mdb.greenplum.v1.LogErrorVerbosity\x12H\n\x10log_min_messages\x18  \x01(\x0e\x32..yandex.cloud.mdb.greenplum.v1.LogLevelMessage\"\xf5\x01\n\x13GreenplumConfigSet6\x12O\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32/.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6B\x04\xe8\xc7\x31\x01\x12\x44\n\x0buser_config\x18\x02 \x01(\x0b\x32/.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6\x12G\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32/.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6\"\x8d\x02\n\x19\x43onnectionPoolerConfigSet\x12U\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32\x35.yandex.cloud.mdb.greenplum.v1.ConnectionPoolerConfigB\x04\xe8\xc7\x31\x01\x12J\n\x0buser_config\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.mdb.greenplum.v1.ConnectionPoolerConfig\x12M\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32\x35.yandex.cloud.mdb.greenplum.v1.ConnectionPoolerConfig\"\x81\x02\n\x16GreenplumConfigSetCBDB\x12R\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32\x32.yandex.cloud.mdb.greenplum.v1.GreenplumConfigCBDBB\x04\xe8\xc7\x31\x01\x12G\n\x0buser_config\x18\x02 \x01(\x0b\x32\x32.yandex.cloud.mdb.greenplum.v1.GreenplumConfigCBDB\x12J\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32\x32.yandex.cloud.mdb.greenplum.v1.GreenplumConfigCBDB*]\n\x11LogErrorVerbosity\x12#\n\x1fLOG_ERROR_VERBOSITY_UNSPECIFIED\x10\x00\x12\t\n\x05TERSE\x10\x01\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x02\x12\x0b\n\x07VERBOSE\x10\x03*\xb4\x01\n\x0fLogLevelMessage\x12!\n\x1dLOG_LEVEL_MESSAGE_UNSPECIFIED\x10\x00\x12\n\n\x06\x44\x45\x42UG5\x10\x01\x12\n\n\x06\x44\x45\x42UG4\x10\x02\x12\n\n\x06\x44\x45\x42UG3\x10\x03\x12\n\n\x06\x44\x45\x42UG2\x10\x04\x12\n\n\x06\x44\x45\x42UG1\x10\x05\x12\x08\n\x04INFO\x10\x06\x12\n\n\x06NOTICE\x10\x07\x12\x0b\n\x07WARNING\x10\x08\x12\t\n\x05\x45RROR\x10\t\x12\t\n\x05\x46\x41TAL\x10\n\x12\t\n\x05PANIC\x10\x0b*R\n\x0cLogStatement\x12\x1d\n\x19LOG_STATEMENT_UNSPECIFIED\x10\x00\x12\x08\n\x04NONE\x10\x01\x12\x07\n\x03\x44\x44L\x10\x02\x12\x07\n\x03MOD\x10\x03\x12\x07\n\x03\x41LL\x10\x04*\x94\x01\n\x0fGPAutostatsMode\x12!\n\x1dGP_AUTOSTATS_MODE_UNSPECIFIED\x10\x00\x12\x1a\n\x16GP_AUTOSTATS_MODE_NONE\x10\x01\x12\x1f\n\x1bGP_AUTOSTATS_MODE_ON_CHANGE\x10\x02\x12!\n\x1dGP_AUTOSTATS_MODE_ON_NO_STATS\x10\x03\x42p\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplumb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.greenplum.v1.config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplum'
  _globals['_BACKGROUNDACTIVITYSTARTAT'].fields_by_name['hours']._loaded_options = None
  _globals['_BACKGROUNDACTIVITYSTARTAT'].fields_by_name['hours']._serialized_options = b'\372\3071\0040-23'
  _globals['_BACKGROUNDACTIVITYSTARTAT'].fields_by_name['minutes']._loaded_options = None
  _globals['_BACKGROUNDACTIVITYSTARTAT'].fields_by_name['minutes']._serialized_options = b'\372\3071\0040-59'
  _globals['_TABLESIZES'].fields_by_name['starts']._loaded_options = None
  _globals['_TABLESIZES'].fields_by_name['starts']._serialized_options = b'\202\3101\003<=4'
  _globals['_ANALYZEANDVACUUM'].fields_by_name['analyze_timeout']._loaded_options = None
  _globals['_ANALYZEANDVACUUM'].fields_by_name['analyze_timeout']._serialized_options = b'\372\3071\n7200-86399'
  _globals['_ANALYZEANDVACUUM'].fields_by_name['vacuum_timeout']._loaded_options = None
  _globals['_ANALYZEANDVACUUM'].fields_by_name['vacuum_timeout']._serialized_options = b'\372\3071\n7200-86399'
  _globals['_QUERYKILLER'].fields_by_name['max_age']._loaded_options = None
  _globals['_QUERYKILLER'].fields_by_name['max_age']._serialized_options = b'\372\3071\0071-86400'
  _globals['_GREENPLUMCONFIG6'].fields_by_name['max_connections']._loaded_options = None
  _globals['_GREENPLUMCONFIG6'].fields_by_name['max_connections']._serialized_options = b'\372\3071\00750-1000'
  _globals['_GREENPLUMCONFIG6'].fields_by_name['max_slot_wal_keep_size']._loaded_options = None
  _globals['_GREENPLUMCONFIG6'].fields_by_name['max_slot_wal_keep_size']._serialized_options = b'\372\3071\0160-214748364800'
  _globals['_GREENPLUMCONFIG6'].fields_by_name['gp_workfile_limit_per_segment']._loaded_options = None
  _globals['_GREENPLUMCONFIG6'].fields_by_name['gp_workfile_limit_per_segment']._serialized_options = b'\372\3071\003>=0'
  _globals['_GREENPLUMCONFIG6'].fields_by_name['gp_workfile_limit_per_query']._loaded_options = None
  _globals['_GREENPLUMCONFIG6'].fields_by_name['gp_workfile_limit_per_query']._serialized_options = b'\372\3071\0170-1099511627776'
  _globals['_GREENPLUMCONFIG6'].fields_by_name['gp_workfile_limit_files_per_query']._loaded_options = None
  _globals['_GREENPLUMCONFIG6'].fields_by_name['gp_workfile_limit_files_per_query']._serialized_options = b'\372\3071\0100-100000'
  _globals['_GREENPLUMCONFIG6'].fields_by_name['max_prepared_transactions']._loaded_options = None
  _globals['_GREENPLUMCONFIG6'].fields_by_name['max_prepared_transactions']._serialized_options = b'\372\3071\01050-10000'
  _globals['_GREENPLUMCONFIG6'].fields_by_name['max_statement_mem']._loaded_options = None
  _globals['_GREENPLUMCONFIG6'].fields_by_name['max_statement_mem']._serialized_options = b'\372\3071\027134217728-1099511627776'
  _globals['_GREENPLUMCONFIG6'].fields_by_name['gp_max_slices']._loaded_options = None
  _globals['_GREENPLUMCONFIG6'].fields_by_name['gp_max_slices']._serialized_options = b'\372\3071\00610-100'
  _globals['_GREENPLUMCONFIG6'].fields_by_name['gp_cached_segworkers_threshold']._loaded_options = None
  _globals['_GREENPLUMCONFIG6'].fields_by_name['gp_cached_segworkers_threshold']._serialized_options = b'\372\3071\0040-10'
  _globals['_GREENPLUMCONFIG6'].fields_by_name['lock_timeout']._loaded_options = None
  _globals['_GREENPLUMCONFIG6'].fields_by_name['lock_timeout']._serialized_options = b'\372\3071\0140-2147483647'
  _globals['_GREENPLUMCONFIG6'].fields_by_name['idle_in_transaction_session_timeout']._loaded_options = None
  _globals['_GREENPLUMCONFIG6'].fields_by_name['idle_in_transaction_session_timeout']._serialized_options = b'\372\3071\0140-2147483647'
  _globals['_GREENPLUMCONFIG6'].fields_by_name['runaway_detector_activation_percent']._loaded_options = None
  _globals['_GREENPLUMCONFIG6'].fields_by_name['runaway_detector_activation_percent']._serialized_options = b'\372\3071\0050-100'
  _globals['_GREENPLUMCONFIG6'].fields_by_name['gp_vmem_protect_segworker_cache_limit']._loaded_options = None
  _globals['_GREENPLUMCONFIG6'].fields_by_name['gp_vmem_protect_segworker_cache_limit']._serialized_options = b'\372\3071\0060-4096'
  _globals['_GREENPLUMCONFIG6'].fields_by_name['gp_max_plan_size']._loaded_options = None
  _globals['_GREENPLUMCONFIG6'].fields_by_name['gp_max_plan_size']._serialized_options = b'\372\3071\0140-2147483647'
  _globals['_GREENPLUMCONFIG6'].fields_by_name['gp_autostats_on_change_threshold']._loaded_options = None
  _globals['_GREENPLUMCONFIG6'].fields_by_name['gp_autostats_on_change_threshold']._serialized_options = b'\372\3071\0140-2147483647'
  _globals['_GREENPLUMCONFIG6'].fields_by_name['gp_resource_group_memory_limit']._loaded_options = None
  _globals['_GREENPLUMCONFIG6'].fields_by_name['gp_resource_group_memory_limit']._serialized_options = b'\372\3071\0070.1-0.8'
  _globals['_GREENPLUMCONFIG6'].fields_by_name['log_min_duration_statement']._loaded_options = None
  _globals['_GREENPLUMCONFIG6'].fields_by_name['log_min_duration_statement']._serialized_options = b'\372\3071\r-1-2147483647'
  _globals['_GREENPLUMCONFIG6'].fields_by_name['master_shared_buffers']._loaded_options = None
  _globals['_GREENPLUMCONFIG6'].fields_by_name['master_shared_buffers']._serialized_options = b'\372\3071\0221048576-2147483647'
  _globals['_GREENPLUMCONFIG6'].fields_by_name['max_locks_per_transaction']._loaded_options = None
  _globals['_GREENPLUMCONFIG6'].fields_by_name['max_locks_per_transaction']._serialized_options = b'\372\3071\010128-2048'
  _globals['_GREENPLUMCONFIG6'].fields_by_name['segment_shared_buffers']._loaded_options = None
  _globals['_GREENPLUMCONFIG6'].fields_by_name['segment_shared_buffers']._serialized_options = b'\372\3071\0221048576-2147483647'
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['max_connections']._loaded_options = None
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['max_connections']._serialized_options = b'\372\3071\00750-1000'
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['max_slot_wal_keep_size']._loaded_options = None
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['max_slot_wal_keep_size']._serialized_options = b'\372\3071\0160-214748364800'
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['gp_workfile_limit_per_segment']._loaded_options = None
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['gp_workfile_limit_per_segment']._serialized_options = b'\372\3071\003>=0'
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['gp_workfile_limit_per_query']._loaded_options = None
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['gp_workfile_limit_per_query']._serialized_options = b'\372\3071\0170-1099511627776'
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['gp_workfile_limit_files_per_query']._loaded_options = None
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['gp_workfile_limit_files_per_query']._serialized_options = b'\372\3071\0100-100000'
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['max_prepared_transactions']._loaded_options = None
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['max_prepared_transactions']._serialized_options = b'\372\3071\01050-10000'
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['max_statement_mem']._loaded_options = None
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['max_statement_mem']._serialized_options = b'\372\3071\027134217728-1099511627776'
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['gp_max_slices']._loaded_options = None
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['gp_max_slices']._serialized_options = b'\372\3071\00610-100'
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['gp_cached_segworkers_threshold']._loaded_options = None
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['gp_cached_segworkers_threshold']._serialized_options = b'\372\3071\0040-10'
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['lock_timeout']._loaded_options = None
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['lock_timeout']._serialized_options = b'\372\3071\0140-2147483647'
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['idle_in_transaction_session_timeout']._loaded_options = None
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['idle_in_transaction_session_timeout']._serialized_options = b'\372\3071\0140-2147483647'
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['runaway_detector_activation_percent']._loaded_options = None
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['runaway_detector_activation_percent']._serialized_options = b'\372\3071\0050-100'
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['gp_vmem_protect_segworker_cache_limit']._loaded_options = None
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['gp_vmem_protect_segworker_cache_limit']._serialized_options = b'\372\3071\0060-4096'
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['gp_max_plan_size']._loaded_options = None
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['gp_max_plan_size']._serialized_options = b'\372\3071\0140-2147483647'
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['gp_autostats_on_change_threshold']._loaded_options = None
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['gp_autostats_on_change_threshold']._serialized_options = b'\372\3071\0140-2147483647'
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['gp_resource_group_memory_limit']._loaded_options = None
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['gp_resource_group_memory_limit']._serialized_options = b'\372\3071\0070.1-0.8'
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['log_min_duration_statement']._loaded_options = None
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['log_min_duration_statement']._serialized_options = b'\372\3071\r-1-2147483647'
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['master_shared_buffers']._loaded_options = None
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['master_shared_buffers']._serialized_options = b'\372\3071\0221048576-2147483647'
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['max_locks_per_transaction']._loaded_options = None
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['max_locks_per_transaction']._serialized_options = b'\372\3071\010128-2048'
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['segment_shared_buffers']._loaded_options = None
  _globals['_GREENPLUMCONFIGCBDB'].fields_by_name['segment_shared_buffers']._serialized_options = b'\372\3071\0221048576-2147483647'
  _globals['_GREENPLUMCONFIGSET6'].fields_by_name['effective_config']._loaded_options = None
  _globals['_GREENPLUMCONFIGSET6'].fields_by_name['effective_config']._serialized_options = b'\350\3071\001'
  _globals['_CONNECTIONPOOLERCONFIGSET'].fields_by_name['effective_config']._loaded_options = None
  _globals['_CONNECTIONPOOLERCONFIGSET'].fields_by_name['effective_config']._serialized_options = b'\350\3071\001'
  _globals['_GREENPLUMCONFIGSETCBDB'].fields_by_name['effective_config']._loaded_options = None
  _globals['_GREENPLUMCONFIGSETCBDB'].fields_by_name['effective_config']._serialized_options = b'\350\3071\001'
  _globals['_LOGERRORVERBOSITY']._serialized_start=7466
  _globals['_LOGERRORVERBOSITY']._serialized_end=7559
  _globals['_LOGLEVELMESSAGE']._serialized_start=7562
  _globals['_LOGLEVELMESSAGE']._serialized_end=7742
  _globals['_LOGSTATEMENT']._serialized_start=7744
  _globals['_LOGSTATEMENT']._serialized_end=7826
  _globals['_GPAUTOSTATSMODE']._serialized_start=7829
  _globals['_GPAUTOSTATSMODE']._serialized_end=7977
  _globals['_RESOURCES']._serialized_start=140
  _globals['_RESOURCES']._serialized_end=220
  _globals['_CONNECTIONPOOLERCONFIG']._serialized_start=223
  _globals['_CONNECTIONPOOLERCONFIG']._serialized_end=561
  _globals['_CONNECTIONPOOLERCONFIG_POOLMODE']._serialized_start=494
  _globals['_CONNECTIONPOOLERCONFIG_POOLMODE']._serialized_end=561
  _globals['_BACKGROUNDACTIVITYSTARTAT']._serialized_start=563
  _globals['_BACKGROUNDACTIVITYSTARTAT']._serialized_end=642
  _globals['_TABLESIZES']._serialized_start=644
  _globals['_TABLESIZES']._serialized_end=739
  _globals['_ANALYZEANDVACUUM']._serialized_start=742
  _globals['_ANALYZEANDVACUUM']._serialized_end=972
  _globals['_BACKGROUNDACTIVITIESCONFIG']._serialized_start=975
  _globals['_BACKGROUNDACTIVITIESCONFIG']._serialized_end=1225
  _globals['_QUERYKILLER']._serialized_start=1228
  _globals['_QUERYKILLER']._serialized_end=1366
  _globals['_QUERYKILLERSCRIPTS']._serialized_start=1369
  _globals['_QUERYKILLERSCRIPTS']._serialized_end=1586
  _globals['_MASTERSUBCLUSTERCONFIG']._serialized_start=1588
  _globals['_MASTERSUBCLUSTERCONFIG']._serialized_end=1673
  _globals['_SEGMENTSUBCLUSTERCONFIG']._serialized_start=1675
  _globals['_SEGMENTSUBCLUSTERCONFIG']._serialized_end=1761
  _globals['_GREENPLUMCONFIG6']._serialized_start=1764
  _globals['_GREENPLUMCONFIG6']._serialized_end=4258
  _globals['_GREENPLUMCONFIGCBDB']._serialized_start=4261
  _globals['_GREENPLUMCONFIGCBDB']._serialized_end=6684
  _globals['_GREENPLUMCONFIGSET6']._serialized_start=6687
  _globals['_GREENPLUMCONFIGSET6']._serialized_end=6932
  _globals['_CONNECTIONPOOLERCONFIGSET']._serialized_start=6935
  _globals['_CONNECTIONPOOLERCONFIGSET']._serialized_end=7204
  _globals['_GREENPLUMCONFIGSETCBDB']._serialized_start=7207
  _globals['_GREENPLUMCONFIGSETCBDB']._serialized_end=7464
# @@protoc_insertion_point(module_scope)
